@@ -3,8 +3,9 @@
 #    act like a button for quick clicks
 #    act like a menu if hold down button
 #
-# 22 July 1997 by Tom Phelps (phelps@ACM.org),
+# 1997 July 22 by Tom Phelps (phelps@ACM.org),
 #    on top of Tk's button and menubutton bindings
+# 2003 March 12 updated for Tk 8.4 (tkPriv => ::tk::Priv)
 #
 
 # To use, create a menubutton and pass it and the command to execute
@@ -19,15 +20,6 @@
 # If you disable the original menubutton, both button and menubutton
 #    behaviors are disabled.
 
-# Namespace use:
-#   buttonmenubutton proc name
-#   bmb prefix for proc names
-#   bmb() array
-
-# To do
-#   stash code in a namespace?
-#   seems to be some interference with vwait (as by alert box)
-
 
 set bmb(menubutton-delay) 250
 set bmb(type) ""
@@ -40,36 +32,36 @@ set bmb(x) ""; set bmb(y) ""
 proc buttonmenubutton {mb {cmd ""}} {
 	global bmb
 
-	if {![string equal [winfo class $mb] "Menubutton"]} {error "$mb must be a menubutton"}
+	if {[winfo class $mb] ne "Menubutton"} {error "$mb must be a menubutton"}
 
 	# store commands
 	set bmb($mb) $cmd
 
 	# on Button-1, assume it's a click, correct later according to timer
 	bind $mb <Button-1> {if [catch {bmbB1Down %W %X %Y}] break}
-	bind $mb <B1-Motion> {if {[string equal $bmb(type) "button"]} break}
+	bind $mb <B1-Motion> {if {$bmb(type) eq "button"} break}
 	bind $mb <ButtonRelease-1> {if [catch {bmbB1Up %W}] break}
 }
 
 proc bmbB1Down {w x y} {
-	global bmb tkPriv
+	global bmb
 
 	# would be nice if break and continue could be thrown as exceptions
 	# to be recognized in bindings
-	if {![string equal $tkPriv(postedMb) ""]} {tkMbButtonUp $w; return -code break}
-	if {![string equal $bmb(type) ""]} {return -code break}
+	if {$::tk::Priv(postedMb) ne ""} {::tk::MbButtonUp $w; return -code break}
+	if {$bmb(type) ne ""} {return -code break}
 
 	set bmb(w) $w; set bmb(relief) [$w cget -relief]
 	set bmb(x) $x; set bmb(y) $y
 
 	# if no command, treat as a menu straight away
-	if {[string equal $bmb($w) ""]} {set bmb(type) ""; return}; # continue with menubutton bindings
+	if {$bmb($w) eq ""} {set bmb(type) ""; return}; # continue with menubutton bindings
 
 	# pretend you're a button at first
 	set bmb(type) "button"
-	tkButtonDown $w
+	catch {[::tk::ButtonDown $w]}; # brute force: -repeatdelay on button only not menubutton
 	# if have a menu, possibility of converting to menubutton operation
-	if {![string equal [$w cget -menu] ""] && ![string equal [[$w cget -menu] index end] "none"]} {
+	if {[$w cget -menu] ne "" && [[$w cget -menu] index end] ne "none"} {
 		set bmb(after) [after $bmb(menubutton-delay) bmbConvert]
 	}
 	return -code break
@@ -78,36 +70,36 @@ proc bmbB1Down {w x y} {
 proc bmbB1Up {w} {
 	global bmb
 
-	if {[string equal $bmb(type) "button"]} {bmbButtonUp $w} else {tkMbButtonUp $w}
+	if {$bmb(type) eq "button"} {bmbButtonUp $w} else {::tk::MbButtonUp $w}
 	# clean up for button
 	set bmb(type) ""
-	if {![string equal $bmb(after) ""]} {after cancel $bmb(after)}
+	if {$bmb(after) ne ""} {after cancel $bmb(after)}
 	set bmb(after) ""
 	$bmb(w) configure -relief $bmb(relief)
 	return -code break
 }
 
 proc bmbConvert {} {
-	global bmb tkPriv
+	global bmb
 
 	# if already finished as button, we're done
-	if {[string equal $bmb(type) ""]} return
-	set tkPriv(buttonWindow) ""; # clean up
+	if {$bmb(type) eq ""} return
+	set ::tk::Priv(buttonWindow) ""; # clean up
 	set bmb(after) ""
 
 	$bmb(w) configure -relief $bmb(relief)
 	set bmb(type) ""; # give control over to the menu system
-	set tkPriv(inMenubutton) $bmb(w)
-	tkMbPost $bmb(w) $bmb(x) $bmb(y)
+	set ::tk::Priv(inMenubutton) $bmb(w)
+	::tk::MbPost $bmb(w) $bmb(x) $bmb(y)
 	$bmb(w) configure -relief sunken; # that's how Netscape does it
 }
 
 proc bmbButtonUp {w} {
-	global bmb tkPriv
+	global bmb
 
-	if {[string equal $w $tkPriv(buttonWindow)]} {
-		set tkPriv(buttonWindow) ""
-		if {![string equal [$w cget -state] "disabled"]} {
+	if {$w eq $::tk::Priv(buttonWindow)} {
+		set ::tk::Priv(buttonWindow) ""
+		if {[$w cget -state] ne "disabled"} {
 			uplevel #0 $bmb($w)
 		}
 	}
