@@ -12,7 +12,7 @@ proc manReadSects {{w .man} {force 0} {msg "Building database ..."}} {
 	set manx(hunkcnt) 0
 	set hunkcode(0) manReadRecentDone
 	# kill one in progress, if any
-	if {![string equal $manx(hunkid) ""]} {after cancel $manx(hunkid)}
+	if {$manx(hunkid) ne ""} {after cancel $manx(hunkid)}
 
 	set manx(manList) ""; set manx(manTitleList) ""; set manx(mandot) ""
 	set lastv ""
@@ -23,7 +23,7 @@ proc manReadSects {{w .man} {force 0} {msg "Building database ..."}} {
 	set buildtime [time {
 	foreach i $mani(manList) j $mani(manTitleList) {
 		set nowv [string index $i 0]
-		if {[string equal $nowv $lastv]} {set more [string range $i 1 end]} else {set more " $i"}
+		if {$nowv eq $lastv} {set more [string range $i 1 end]} else {set more " $i"}
 		set lastv $nowv
 		manWinstdout $w "[manWinstdout $w]$more" 1
 		if {[set cnt [manReadSection $i]]} {
@@ -83,7 +83,7 @@ proc manLatestMan {root} {
 
 	set men [glob -nocomplain "$root/man?*"]
 	# in cat-only situation?
-	if {[string equal $men ""]} {
+	if {$men eq ""} {
 		set men [glob -nocomplain "$root/*"]
 		#if [catch {set men [exec $man(find) $root -type d -print]} info] { set men $info }
 	}
@@ -142,7 +142,7 @@ proc manReadRecentDone {} {
 
 DEBUG {puts "RECENT DONE, hunk array: [array names hunk]"}
 	foreach n [array names hunk] {
-		if {![string equal $hunk($n) ""]} {lappend manx(newmen) [list $n [lsort $hunk($n)]]}
+		if {$hunk($n) ne ""} {lappend manx(newmen) [list $n [lsort $hunk($n)]]}
 	}
 
 	.vols entryconfigure "Recently*" -state normal -label "Recently added/changed"
@@ -175,7 +175,7 @@ DEBUG { puts -nonewline stderr $n }
 	# need -maxdepth *0* on find for SGI's nested directories, but only gfind has it so homebrew
 	set recentdef [expr {[clock seconds]-$man(recentdays)*24*60*60}]
 	# make this an after idle event.  recent section not available for ~10 seconds--who'll notice?
-	
+
 	# chop up files to mtime into hunks that aren't noticable to user interaction
 	# would like to have threads for this
 	# => just do this on demand when choose that section?
@@ -255,10 +255,10 @@ DEBUG { puts -nonewline stderr $n }
 				if {[regexp {\.} $kt]} {lappend manx(mandot) $kt}
 				incr cati
 			}
-			while {[string equal [lindex $cat $cati] $k]} {incr cati}
+			while {[lindex $cat $cati] eq $k} {incr cati}
 
 			# elsewhere handle multiple pages in same man-cat pair with same name but different suffixes, e.g., printf.3s and printf.3v
-			if {[string equal $k $lastman]} continue
+			if {$k eq $lastman} continue
 			lappend unique $k
 			if {[regexp {\.} $k]} {lappend manx(mandot) $k}
 			set lastman $k
@@ -267,7 +267,7 @@ DEBUG { puts -nonewline stderr $n }
 
 		set manc($n,$i) $unique
 		if {[llength $strays]} {
-			if {[string equal $manx(stray-warnings) ""]} {set manx(stray-warnings) "Stray cats (formatted pages in .../man/catN without corresponding source in .../man/manN)\n"}
+			if {$manx(stray-warnings) eq ""} {set manx(stray-warnings) "Stray cats (formatted pages in .../man/catN without corresponding source in .../man/manN)\n"}
 			append manx(stray-warnings) "$d2\n\t$strays\n"
 		}
 
@@ -301,7 +301,7 @@ proc manShowSection {w n} {
 
 	set head [lindex $manx(manTitleList) [lsearch $manx(manList) $n]]
 
-	if {[string equal $mani($n,form) ""]} {
+	if {$mani($n,form) eq ""} {
 		cursorBusy
 		manWinstdout $w "Formatting $head ..." 1
 		set mani($n,shortvolname) [manFormatSect $n]
@@ -309,7 +309,7 @@ proc manShowSection {w n} {
 	}
 
 	set info $head
-#	if {![string equal $mani($n,update) ""]} { append info "   (last update [textmanip::recently $mani($n,update)])" }
+#	if {$mani($n,update) ne ""} { append info "   (last update [textmanip::recently $mani($n,update)])" }
 	manWinstdout $w $info
 	manSetSect $w $n
 
@@ -329,15 +329,15 @@ proc manShowSection {w n} {
 	$w.vols configure -text $mani($n,shortvolname); set bmb($w.vols) "manShowSection $w $n"
 	set manx(name$w) $head
 
-#	if {[string equal $man(hyperclick) "double"]} {set mod "Double-" } else {set mod ""}
-	set mod [expr {[string equal $man(hyperclick) "double"]?"Double-":""}]
+#	if {$man(hyperclick) eq "double"} {set mod "Double-" } else {set mod ""}
+	set mod [expr {$man(hyperclick) eq "double"? "Double-" : ""}]
 	set ev "<${mod}ButtonRelease-1>"
 #	$t tag bind hyper $ev {}
 #	manHyper $w
-	if {[string equal $n "glimpse"]} {
-		$t tag bind hyper $ev "+if {\[string equal \$manx(glimpse-pattern) \$manx(search,string$w)\]} {$w.search.s invoke}"
+	if {$n eq "glimpse"} {
+		$t tag bind hyper $ev "+if {\$manx(glimpse-pattern) eq \$manx(search,string$w)} {$w.search.s invoke}"
 #; catch {$w.sections.m invoke {Collapse all}}"
-	} elseif {[string equal $n "glimpseindex"]} {
+	} elseif {$n eq "glimpseindex"} {
 		$t tag bind hyper $ev "+
 			if {\$manx(hotman$t)!={}} { incr stat(man-hyper); manGlimpse \$manx(hotman$t) -w \$manx(out$w) }
 		"
@@ -350,7 +350,7 @@ proc manFormatSect {n} {
 
 	set form {}; set cnt 0
 
-	if {[string equal $n "high"]} {
+	if {$n eq "high"} {
 		lappend form "\tTime of last annotation\n" {}
 		set lastletter ""; set lastday ""
 		set sortedlist {}
@@ -368,20 +368,20 @@ proc manFormatSect {n} {
 			set sortedlist [lsort -integer -index 1 -decreasing $tuples]
 		}
 		foreach k $sortedlist {
-# || [string equal $k "*"]
+# || $k eq "*"
 			foreach {name sec} $k break
 
 			# name
 			if {$manx(highsortby)==0} {
 				set letter [string tolower [string index [file tail $name] 0]]
-				if {![string equal $letter $lastletter]} {lappend form "$letter  " h2; set lastletter $letter}
+				if {$letter ne $lastletter} {lappend form "$letter  " h2; set lastletter $letter}
 			}
 			lappend form $name manref
 
 			# time
 			regexp {(\d+:[\d:]+)*(.*)} [textmanip::recently $sec] all time day
 			if {$manx(highsortby)==1} {
-				if {[string equal $day $lastday]} {set day ""} else {set lastday $day}
+				if {$day eq $lastday} {set day ""} else {set lastday $day}
 			}
 			if {$sec>0} { lappend form "\t$time$day" i }
 			lappend form "\n" {}
@@ -393,7 +393,7 @@ proc manFormatSect {n} {
 		set mani(high,form) $form
 		return "Highlighted"
 
-	} elseif {[string equal $n "recent"]} {
+	} elseif {$n eq "recent"} {
 		set first 1
 		foreach i $manx(newmen) {
 			foreach {vol names} $i {}
@@ -413,7 +413,7 @@ proc manFormatSect {n} {
 		set mani(recent,form) $form
 		return "Recent"
 
-	} elseif {[string equal $n "census"]} {
+	} elseif {$n eq "census"} {
 		lappend form "\tTimes read\tTime last read\n" {}
 
 		# can't use array get because it makes value into sublist
@@ -429,7 +429,7 @@ proc manFormatSect {n} {
 				foreach {name seencnt lastread} $tuple break
 				regexp {(\d+:[\d:]+)*(.*)} [textmanip::recently $lastread] all time day
 				if {$manx(censussortby)==2} {
-					if {[string equal $day $lastday]} {set day ""} else {set lastday $day}
+					if {$day eq $lastday} {set day ""} else {set lastday $day}
 				}
 				lappend form $name manref "\t$seencnt\t" {} "$time$day" i "\n" {}
 			}
@@ -437,20 +437,20 @@ proc manFormatSect {n} {
 		set mani($n,form) $form; set mani($n,cnt) $cnt
 		return [lindex {Alpha Frequency Chrono} $manx(censussortby)]
 
-#	} elseif {[string equal $n "glimpsefreq"]} {
-	} elseif {[string equal $n "glimpseindex"]} {
+#	} elseif {$n eq "glimpsefreq"} {
+	} elseif {$n eq "glimpseindex"} {
 		manGlimpseIndexShow
 		return "Index"
 	}
 
-	if {[string equal $n "all"]} {set sect $man(manList)} else {set sect $n}
+	if {$n eq "all"} {set sect $man(manList)} else {set sect $n}
 	set ltmp {}
 	foreach subvar [manSearchArray $sect] {
 		# can't use lappend, at least directly
 		append ltmp $manc($subvar) " "
 	}
 
-	if {[string equal $man(volcol) "0"]} {set sep "   "} else {set sep "\t"}
+	if {$man(volcol) eq "0"} {set sep "   "} else {set sep "\t"}
 	set cnt 0
 
 	# specialized version of uniqlist
@@ -460,14 +460,14 @@ proc manFormatSect {n} {
 		# no extensions anymore, just the name root
 		set il [string tolower [string index $ir 0]]
 
-		if {![string equal $pl $il] && [llength $sub]} {
-# && ($n==3 || ![string match {[A-Z]} [string index $i 0]])} {
+		if {$pl ne $il && [llength $sub]} {
+# && ($n==3 || ![string match {[A-Z]} [string index $i 0]])} 
 			lappend form [join $sub "\t"] manref "\n\n" {}
 			set sub {}
 			set pl $il
 		}
 		# within same section $pr!=$ir always, but in (all) can have duplicates
-		if {![string equal $pr $ir]} {lappend sub $ir}
+		if {$pr ne $ir} {lappend sub $ir}
 		set pr $ir
 		incr cnt
 	}
@@ -495,12 +495,12 @@ proc manMakeVolList {{recentok 0}} {
 	set m .vols
 	destroy $m; menu $m -tearoff no -font gui
 
-	if {![string equal $man(texinfodir) ""]} {
+	if {$man(texinfodir) ne ""} {
 		$m add command -label "Texinfo" -command "manTextOpen \$curwin; texiTop \$man(texinfodir) \$curwin.show; \$curwin.show tag add volume 1.0 end; manTextClose \$curwin; \$curwin.vols configure -text Texinfo; set bmb(\$curwin.vols) {$m invoke Texinfo}"
 		#"manShowSection \$curwin texi"
 	}
 
-	if {![string equal $man(rfcdir) ""] && [file exists [file join $man(rfcdir) "rfc-index.txt"]]} {
+	if {$man(rfcdir) ne "" && [file exists [file join $man(rfcdir) "rfc-index.txt"]]} {
 		$m add command -label "Request for Comments (RFC)" -command {
 			manShowText $man(rfcdir)/rfc-index.txt
 			searchboxSearch {^\d\d\d\d} 1 1 rfcxref $curwin.show $curwin
@@ -546,14 +546,14 @@ proc manMakeVolList {{recentok 0}} {
 		}
 
 		# everybody gets added somewhere, under some name
-		if {[string equal $i "census"]} {
+		if {$i eq "census"} {
 			$menu add cascade -label $label -menu [set m2 .vols.seensortby]; menu $m2 -tearoff no
 			foreach {label index} {
 				"sort by frequency" 1   "sort chronologically" 2  "sort alphabetically" 0
 			} {
 				$m2 add command -label $label -command "set mani(census,form) {}; set manx(censussortby) $index; manShowSection \$curwin census; \$curwin.show see 1.0"
 			}
-		} elseif {[string equal $i "high"]} {
+		} elseif {$i eq "high"} {
 			$menu add cascade -label $label -menu [set m2 .vols.highsortby]; menu $m2 -tearoff no
 			foreach {label index} {
 				"sort chronologically" 1  "sort alphabetically" 0
@@ -596,7 +596,7 @@ proc manCatClear {} {
 	manCatClearRecursive $man(fsstnddir)
 }
 
-proc manVersionClearRecursive {dir} {
+proc manCatClearRecursive {dir} {
 	foreach f [glob -nocomplain $dir] {
 		if {[file isdirectory $f]} {manCatClearRecursive $f}
 	}
