@@ -19,11 +19,11 @@ proc manGlimpse {name {opts ""} {w .man}} {
 			set name [tr $name {\s} ";"]
 		}
 	}
-	if {[string equal $man(indexglimpse) "distributed"]} {
+	if {$man(indexglimpse) eq "distributed"} {
 		set texindexdir [file join $man(texinfodir) glimpse]
-		if {![string equal $man(texinfodir) ""] && [file readable $texindexdir]} {lappend dirs $texindexdir}
+		if {$man(texinfodir) ne "" && [file readable $texindexdir]} {lappend dirs $texindexdir}
 
-		if {![string equal $man(rfcdir) ""] && [file readable $man(rfcdir)]} {lappend dirs $man(rfcdir)}
+		if {$man(rfcdir) ne "" && [file readable $man(rfcdir)]} {lappend dirs $man(rfcdir)}
 		foreach dir $man(indexalso) { if {[file readable $dir]} {lappend dirs $dir} }
 
 		foreach d $manx(paths) {
@@ -50,8 +50,8 @@ proc manGlimpse2 {name dirs {auxopts ""} {w .man}} {
 	set t $w.show; set wi $w.info
 
 	# set name to search for and name to show
-	if {[string equal $name ""]} {set name $manx(man$w)}
-	if {[string equal $name ""]} {
+	if {$name eq ""} {set name $manx(man$w)}
+	if {$name eq ""} {
 		manWinstderr $w "Type in regular expression for full text search"
 		return
 	}
@@ -61,7 +61,7 @@ proc manGlimpse2 {name dirs {auxopts ""} {w .man}} {
 	#set opts "-ly"
 	set opts "-y"
 	if {$man(regexp,case)!=-1 || [string is lower $name]} {append opts "i"}
-	if {![string equal $man(maxglimpse) "none"]} {append opts " -L $man(maxglimpse):0:5"}
+	if {$man(maxglimpse) ne "none"} {append opts " -L $man(maxglimpse):0:5"}
 
 	# kill -w for everybody -- use at your own risk: gotta keep for "perl" and others
 	set g1 "$man(glimpse) $auxopts $opts"
@@ -128,8 +128,8 @@ DEBUG {puts "$g2 -H $d $name"}
 
 	# Texinfo
 	set texindexdir [file join $man(texinfodir) glimpse]
-	if {[string equal $man(texinfodir) ""] || ![file readable $texindexdir]} {set texindexdir ""}
-	if {![string equal $texindexdir ""]} {
+	if {$man(texinfodir) eq "" || ![file readable $texindexdir]} {set texindexdir ""}
+	if {$texindexdir ne ""} {
 #		if ![info exists texi(texinfo,paths)] { -- always compute as may have changed
 #			set texi(texinfo,paths) {}
 			texiDatabase $man(texinfodir)
@@ -148,7 +148,7 @@ DEBUG {puts "$g2 -H $d $name"}
 		# portion of the expression that wasn't matched), then the corresponding subMatchVar
 		# will be set to ``-1 -1'' if -indices has been specified or to an empty string otherwise.
 
-		if {![string equal $texindexdir ""] && [string match [file join $texindexdir "*"] $page]} {
+		if {$texindexdir ne "" && [string match [file join $texindexdir "*"] $page]} {
 #puts "considering $page"
 			set mapped ""
 
@@ -159,7 +159,7 @@ DEBUG {puts "$g2 -H $d $name"}
 				if {[string match /*/$mapto [zapZ $canon]]} {set mapped $canon; break}
 			}
 			# ... else try to match on dir
-			if {[string equal $mapped ""]} {
+			if {$mapped eq ""} {
 				set mapto [file rootname [file tail [file dirname $page]]]
 #puts "\t$mapto"
 				foreach canon $texi(texinfo,paths) {
@@ -167,12 +167,12 @@ DEBUG {puts "$g2 -H $d $name"}
 				}
 			}
 			# you'd better have found it by now
-			if {![string equal $mapped ""] && [lsearch $texifound $mapped]==-1} {lappend texifound [set page $mapped]} else {set page ""}; # ... else continue
+			if {$mapped ne "" && [lsearch $texifound $mapped]==-1} {lappend texifound [set page $mapped]} else {set page ""}; # ... else continue
 #puts "=> $mapped / $page"
 		}
 
 
-		if {[string equal $page ""]} {
+		if {$page eq ""} {
 			# nothing
 		} elseif {[string match "/*" $page]} {
 			lappend foundform "[bolg $page ~]\n" manref
@@ -229,7 +229,7 @@ proc manGlimpseIndexShow {} {
 	global man manx mani curwin
 
 	set gi [file join $man(glimpsestrays) ".glimpse_index"]
-	if {![string equal $man(indexglimpse) "unified"] || ![file readable $gi] || $mani(glimpseindex,update)>[file mtime $gi]} return
+	if {$man(indexglimpse) ne "unified" || ![file readable $gi] || $mani(glimpseindex,update)>[file mtime $gi]} return
 
 	set fid [open $gi]; set indexglimpse [read $fid]; close $fid
 	regsub -all "\002\[^\n\]+" $indexglimpse "" indexglimpse; # offset into partitions -- also \002.... notrail -- 
@@ -242,10 +242,10 @@ proc manGlimpseIndexShow {} {
 	set index {}; set sub {}; set och2 "__"
 	foreach i [lsort $indexglimpse] {
 		set ch2 [string range $i 0 1]
-		if {![string equal $ch2 $och2]} {lappend index [join $sub "\t"] manref "\n\n" {}; set sub {}; set och2 $ch2}
+		if {$ch2 ne $och2} {lappend index [join $sub "\t"] manref "\n\n" {}; set sub {}; set och2 $ch2}
 		lappend sub $i
 	}
-	if {![string equal $sub ""]} {lappend index [join $sub "\t"] manref}
+	if {$sub ne ""} {lappend index [join $sub "\t"] manref}
 
 	set mani(glimpseindex,update) [clock seconds]
 	set mani(glimpseindex,form) $index
@@ -259,7 +259,7 @@ proc manGlimpseFreqShow {} {
 
 	set gi [file join $man(glimpsestrays) ".glimpse_index"]
 	set gp [file join $man(glimpsestrays) ".glimpse_partitions"]
-	if {![string equal $man(indexglimpse) "unified"] || ![file readable $gi] || ![file readable $gp] || $mani(glimpseindex,update)>[file mtime $gi]} return
+	if {$man(indexglimpse) ne "unified" || ![file readable $gi] || ![file readable $gp] || $mani(glimpseindex,update)>[file mtime $gi]} return
 
 	set mani(glimpsefreq,form) 0
 	set fid [open $gi]
@@ -281,10 +281,10 @@ puts "$name $offset"
 	set index {}; set sub {}; set och2 "__"
 	foreach i [lsort $indexglimpse] {
 		set ch2 [string range $i 0 1]
-		if {![string equal $ch2 $och2]} {lappend index [join $sub "\t"] manref "\n\n" {}; set sub {}; set och2 $ch2}
+		if {$ch2 ne $och2} {lappend index [join $sub "\t"] manref "\n\n" {}; set sub {}; set och2 $ch2}
 		lappend sub $i
 	}
-	if {![string equal $sub ""]} {lappend index [join $sub "\t"] manref}
+	if {$sub ne ""} {lappend index [join $sub "\t"] manref}
 
 	set mani(glimpseindex,update) [clock seconds]
 	set mani(glimpseindex,form) $index
@@ -301,14 +301,14 @@ proc manGlimpseIndex {{w .man}} {
 
 	# index over all paths, whether currently on or not
 	set texinfodir $man(texinfodir)
-	if {![string equal $texinfodir ""] && [file writable $texinfodir]} {set texindexdir [file join $texinfodir glimpse]} else {set texinfodir ""}
+	if {$texinfodir ne "" && [file writable $texinfodir]} {set texindexdir [file join $texinfodir glimpse]} else {set texinfodir ""}
 #puts "cd $texindexdir"
 
 	set rfcdir $man(rfcdir)
-	if {[string equal $rfcdir ""] || ![file readable $rfcdir]} {set rfcdir ""}
+	if {$rfcdir eq "" || ![file readable $rfcdir]} {set rfcdir ""}
 
 	# pairs of (dest-dir-of-index list-of-dirs-to-index)
-	if {[string equal $man(indexglimpse) "distributed"]} {
+	if {$man(indexglimpse) eq "distributed"} {
 		set dirpairs {}
 		if {[llength $mani($man(glimpsestrays),dirs)]} {
 			lappend dirpairs [list $man(glimpsestrays) $mani($man(glimpsestrays),dirs)]
@@ -316,22 +316,22 @@ proc manGlimpseIndex {{w .man}} {
 		foreach dir $manx(paths) {
 			lappend dirpairs [list $dir $mani($dir,dirs)]
 		}
-		if {![string equal $texinfodir ""]} {lappend dirpairs [list $texindexdir $texindexdir]}
-		if {![string equal $rfcdir ""] && [file writable $rfcdir]} {lappend dirpairs [list $rfcdir $rfcdir]}
+		if {$texinfodir ne ""} {lappend dirpairs [list $texindexdir $texindexdir]}
+		if {$rfcdir ne "" && [file writable $rfcdir]} {lappend dirpairs [list $rfcdir $rfcdir]}
 		foreach dir $man(indexalso) { if {[file writable $dir]} {lappend dirpairs [$dir $dir]} }
 	} else {
 		set dirs $mani($man(glimpsestrays),dirs)
 		foreach dir $manx(paths) {
 			set dirs [concat $dirs $mani($dir,dirs)]
 		}
-		if {![string equal $texinfodir ""]} {lappend dirs $texindexdir}
-		if {![string equal $rfcdir ""]} {lappend dirs $rfcdir}
+		if {$texinfodir ne ""} {lappend dirs $texindexdir}
+		if {$rfcdir ne ""} {lappend dirs $rfcdir}
 		foreach dir $man(indexalso) { if {[file readable $dir]} {lappend dirs $dir} }
 		set dirpairs [list [list $man(glimpsestrays) $dirs]]
 	}
 
 	# Texinfo files
-	if {![string equal $texinfodir ""]} {
+	if {$texinfodir ne ""} {
 #		if ![info exists texi(texinfo,paths)] { -- always compute as may have changed
 #			set texi(texinfo,paths) {}
 			texiDatabase $man(texinfodir)
@@ -356,7 +356,7 @@ proc manGlimpseIndex {{w .man}} {
 			if {[lsearch $texlns $ln]==-1} {
 				exec ln -s $makeme $nameme; lappend texlns $ln
 				set manx($texindexdir,latest) [max $manx($texindexdir,latest) [file mtime [file join $texinfodir "dir.tkman"]]]
-				if {[string equal $man(indexglimpse) "unified"]} {set $var [max [set $var] $manx($texindexdir,latest)]}
+				if {$man(indexglimpse) eq "unified"} {set $var [max [set $var] $manx($texindexdir,latest)]}
 			}
 		}
 	}
@@ -513,7 +513,7 @@ DEBUG {puts "$man(glimpseindex) -z -H $dir $dirs"}
 			set blankok 0
 			while {![eof $fid]} {
 				gets $fid line
-				if {![regexp {(^This is)} $line] && (![string equal $line ""] || $blankok)} {
+				if {![regexp {(^This is)} $line] && ($line ne "" || $blankok)} {
 					$t insert end "$line\n" tt; $t see end; update idletasks
 					set blankok 1
 				}
