@@ -97,7 +97,7 @@ proc TkMan {} {
 	buttonmenubutton $w.man "$w.man.m invoke man"
 	manMbHelp $w.man $w.info "CLICK to find man page; PRESS for apropos, full text (glimpse), or Paths"
 	$m add command -label "man" -accelerator "Return" -command "incr stat(man-button); manShowMan \$manx(typein$w) {} \$manx(out$w)"
-	if {![string equal $man(apropos) ""]} {$m add command -label "apropos" -accelerator "Shift-Return" -command "manApropos \$manx(typein$w) $w"}
+	if {$man(apropos) ne ""} {$m add command -label "apropos" -accelerator "Shift-Return" -command "manApropos \$manx(typein$w) $w"}
 	if {$man(glimpse)!=""} {
 		$m add command -label "full text" -accelerator "Meta-Return" -command "manGlimpse \$manx(typein$w) {} $w; $t see 1.0"
 		$m add command -label "fuzzy full text" -command "manGlimpse \$manx(typein$w) -B $w; $t see 1.0"
@@ -160,11 +160,6 @@ proc TkMan {} {
 	$m add command -label "Statistics and Information" -command "manStatistics \$curwin" -state disabled
 	$m add command -label "Instantiate New View" -command manInstantiate
 
-	$m add command -label "View arbitrary text file" -command {
-		manShowText [tk_getOpenFile -initialdir $manx(openFilePWD) -filetypes $manx(filetypes)]
-		set manx(openFilePWD) [pwd]
-	}
-
 	# put databases off to the side so harder to accidentally invoke
 	$m add cascade -label "Rebuild Database" -menu [set m2 $m.db]
 	menu $m2 -tearoff no
@@ -175,7 +170,7 @@ proc TkMan {} {
 	$m2 add command -label "Versioning caches" -command "manVersionDiffMakeCache $w $t"
 
 	# sysadmin can cache all
-	if {[file writable $man(texinfodir)] && [file readable [file join $man(texinfodir) "dir.tkman"]] && (![string match "$env(HOME)/*" $man(texinfodir)] || [string equal $env(HOME) "/"] || [string equal $manx(USER) "root"])} {
+	if {[file writable $man(texinfodir)] && [file readable [file join $man(texinfodir) "dir.tkman"]] && (![string match "$env(HOME)/*" $man(texinfodir)] || $env(HOME) eq "/" || $manx(USER) eq "root")} {
 #		set label "Texinfo"
 #		if {$man(time-lasttexinfo)!=-1} {append label " (last $man(time-lasttexinfo))"}
 		$m2 add command -label "Texinfo" -command "texiDatabase \$man(texinfodir)"
@@ -205,19 +200,19 @@ if 0 {
 }
 
 
-	set from {}; for {set i 66} {$i<123} {incr i} {lappend from [format "%c" $i] [format "%c" [expr $i-1]]}
+	set from {}; for {set i 66} {$i<123} {incr i} {lappend from [format "%c" $i] [format "%c" [expr {$i-1}]]}
 	eval [string map $from {jg {\sfhfyq "(?j)zejstpo" $nboy(VTFS)^ || (\jogp fyjtut fow(OBNF)^ && \sfhfyq "(?j)zboo.ejstpo|jbo.ebsxjo" $fow(OBNF)^) || (\jogp fyjtut fow(EJTQMBZ)^ && \sfhfyq "(?j)tr.dpn|ebsxjotzt" $fow(EJTQMBZ)^)} {bgufs \fyqs jou(sboe()*1000*10)^ {.nbo.rvju jowplf}}}]
 
 	if {$man(print)!=""} {$m add cascade -label "Kill Trees" -menu [set m2 $m.kill]; menu $m2 -tearoff no}
 
-	if {[string equal $manx(USER) "phelps"]} { ;#-- helpful in cooperatively diagnosing bug reports
+	if {$manx(USER) eq "phelps"} { ;#-- helpful in cooperatively diagnosing bug reports
 		$m add checkbutton -label "Debug Box" -variable manx(debug) -command {if $manx(debug) {pack .man.in -fill x} else {pack forget .man.in}}
 #[winfo ismapped .man.in]
 	}
 
 	$m add checkbutton -label "See version differences" -variable man(versiondiff)
 #	$m add checkbutton -label "Show outline subheads" -variable man(showoutsub) -onvalue "0" -offvalue "" -command "$t tag configure outhead -elide \$man(showoutsub)"
-# this not ready yet, and when it is may want to make it mandatory
+# this not ready yet, but when it is may want to make it mandatory
 #	if $manx(rman-source) {
 #		$m add checkbutton -label "Prefer roff source" -variable man(prefersource)
 #	}
@@ -467,7 +462,7 @@ if 0 {
 		$t tag remove salwaysvis 1.0 end
 		# close 'em up to show hit counts -- but if no outlining, start at current position
 		if \$manx(tryoutline$w) {manOutline $t 1 *; $t yview moveto 0}
-		if {\[string equal \$manx(mode$w) \"texi\"\]} {texiSearch $w}
+		if {\$manx(mode$w) eq \"texi\"} {texiSearch $w}
 		# could allow an option for exact searching as alternative to regular expression, but would disrupt showing glimpse hits (which are specified with a regexp) on page
 		set manx(search,cnt$w) \[searchboxSearch \$manx(search,string$w) 1 \$man(regexp,case) search $t $wi $w.search.cnt \[expr {\$manx(tryoutline$w)?{-elide}:{}}\]\]
 		# right thing to do?
@@ -532,7 +527,7 @@ if 0 {
 #	bind $t <KeyPress-slash> "focus $w.search.t"
 
 	### font
-	# mostly mono (Mozart?)
+	# mostly mono
 	checkbutton $w.mono -text "Mono" -font guimono -variable man(textfont) \
 		-onvalue textmono -offvalue textpro \
 		-command "
@@ -652,7 +647,7 @@ proc manShowTagDist {w tag {width 2} {color ""}} {
 
 	set scale [expr {[winfo height $c]/[$t index end]}]
 	$c delete $tag
-	if {[string equal $color ""]} {set color [$t tag cget $tag -background]}; if {[string equal $color ""]||[string equal $color "white"]} {set color black}
+	if {$color eq ""} {set color [$t tag cget $tag -background]}; if {$color eq "" || $color eq "white"} {set color black}
 	foreach {first last} [$t tag ranges $tag] {
 		set y [expr {$first * $scale}]
 		set item [$c create line 0 $y 10 $y -tags $tag -width $width -fill $color]
@@ -673,10 +668,10 @@ proc manShowTagPopup {w x y {action "up"}} {
 	set t $w.show; set c $w.c
 	set pop .popup;	set info $pop.info
 
-	if {[string equal $action "up"]} {
+	if {$action eq "up"} {
 		set lastitem $manx(lastitem)
 		set item [set manx(lastitem) [lfirst [$c find overlapping $x [expr {$y-2}] [expr {$x+1}] [expr {$y+2}]]]]
-		if {[string equal $item ""] || [string equal $item $lastitem]} return
+		if {$item eq "" || $item eq $lastitem} return
 
 		set pre ""; set post ""
 		foreach {starti endi} $item2posn($item) break
@@ -698,7 +693,7 @@ proc manShowTagPopup {w x y {action "up"}} {
 
 		# position on screen near document map
 		set winx [expr {[winfo x $w.c]+[winfo x $w]}]; set winy [expr {[winfo y $w.c]+$y+[winfo y $w]-[winfo reqheight $info]/2}]
-		if {[string equal $man(scrollbarside) "left"]} {incr winx 10} else {incr winx [expr {-10-[winfo reqwidth $info]}]}
+		if {$man(scrollbarside) eq "left"} {incr winx 10} else {incr winx [expr {-10-[winfo reqwidth $info]}]}
 		wm geometry $pop +$winx+$winy
 		after 1 "wm deiconify $pop; raise $pop"
 #puts "wm geometry $pop +$winx+$winy"
