@@ -1,11 +1,6 @@
 #--------------------------------------------------
 #
 # Highlights
-#   COULD...
-#		have other annotation types, like in situ text
-#		just attach/clear highlights for current section, rather than entire document
-#			That way, if have annotations that aren't Notemarks, don't have to fault in
-#   Put this effort into Multivalent
 #
 #--------------------------------------------------
 
@@ -17,8 +12,8 @@ proc manHighlightsSetCmd {{incmd add}} {
 	global manx curwin bmb
 	set w $curwin; # or, upvar #0 curwin w
 	set wh $w.high
-	set txt "Hi"; if {[string equal $incmd "add"]} {set txt "+"} elseif {[string equal $incmd "remove"]} {set txt "-"}
-	set cmd "add"; if {[string equal $incmd "remove"]} {set cmd "remove"}
+	set txt "Hi"; if {$incmd eq "add"} {set txt "+"} elseif {$incmd eq "remove"} {set txt "-"}
+	set cmd "add"; if {$incmd eq "remove"} {set cmd "remove"}
 	$wh configure -text $txt; set bmb($wh) "manHighlights $w $cmd"
 }
 
@@ -55,16 +50,16 @@ proc manHighlights {w {cmd update} {auto 0}} {
 	set var high($normalf)
 
 	# try to recover if page moved
-	if {![string equal $normalf ""] && ![info exists $var]} {
+	if {$normalf ne "" && ![info exists $var]} {
 		set movelist {}
 		set tail [file tail $normalf]
 		foreach hi [array names high] {
-			if {[string equal $tail [file tail $hi]]} {lappend movelist $hi}
+			if {$tail eq [file tail $hi]} {lappend movelist $hi}
 		}
 		foreach hi $movelist {
 			if {[lsearch $manx(highdontask) $hi]!=-1} continue
 			if {[catch {glob $hi$manx(zglob)}]} {
-				if {[string equal [tk_messageBox -title "Moved Highlight?" -message "It appears that the highlighted page formerly at\n   $hi\nhas moved to\n   $normalf\nMove highlights too?" -icon question -type okcancel] "ok"]} {
+				if {[tk_messageBox -title "Moved Highlight?" -message "It appears that the highlighted page formerly at\n   $hi\nhas moved to\n   $normalf\nMove highlights too?" -icon question -type okcancel] eq "ok"} {
 					set $var $high($hi); unset high($hi)
 					incr stat(high-carry)
 				} else {lappend manx(highdontask) $hi}
@@ -77,13 +72,13 @@ proc manHighlights {w {cmd update} {auto 0}} {
 	if {[regexp "add|remove" $cmd]} {
 		if {![llength [$t tag nextrange sel 1.0]]} {
 			set errmsg "Select a range of "
-			if {[string equal $cmd "add"]} {append errmsg "characters to highlight"} else {append errmsg "highlighted characters to unhighlight"}
+			if {$cmd eq "add"} {append errmsg "characters to highlight"} else {append errmsg "highlighted characters to unhighlight"}
 
 			manWinstderr $w $errmsg
 			return
 		}
 		$t tag $cmd highlight sel.first sel.last
-		if {[string equal $cmd "add"]} {incr stat(page-highlight-add)} else {incr stat(page-highlight-sub)}
+		if {$cmd eq "add"} {incr stat(page-highlight-add)} else {incr stat(page-highlight-sub)}
 		set mani(high,form) {}
 		selection clear $t
 		set cmd "update"
@@ -92,14 +87,14 @@ proc manHighlights {w {cmd update} {auto 0}} {
 #    not going to be switching between seeing and not seeing all the time,
 #    and in the absence of switching, *want* default behavior!
 #    when do switch or update page (an infrequent happening), natural robustness carries the day
-# elseif {[string equal $cmd "save"]} {
+# elseif {$cmd eq "save"} {
 #		foreach {s e} [lreverse [$t tag ranges diffd] 2] {$t delete $s $e}
 #		set cmd "update"
 #	}
 
 
 	set tags ""
-	if {[string equal $cmd "update"]} {
+	if {$cmd eq "update"} {
 		# new style annotations store date (latest) annotation made
 		set tags [clock seconds]
 		# save some context with tag in hopes of reattaching if the man page changes 
@@ -132,17 +127,16 @@ proc manHighlights {w {cmd update} {auto 0}} {
 				if {[regexp $rele $first all basenum relline charoff secttitle]} {
 #puts "*** decoding baserel $first = js$basenum + $relline l + $charoff c"
 # should have section name as well, but fix this in Multivalent
-# TO DO recovery procedures of section doesn't exist anymore (check sectposns): try supersections if any, faulting in Texinfo along the way
 					set basesect "js$basenum"
 					if {[lsearch $manx(sectposns$w) $basesect]!=-1} {
 						set first [$t index "$basesect linestart+${relline}l+${charoff}c"]
-						if {[string equal $manx(mode$w) "texi"]} {texiFault $t $basesect}
+						if {$manx(mode$w) eq "texi"} {texiFault $t $basesect}
 					}
 				}
 
 				set new [manHighlightAttach $t  $first $firsttxt $predelta $fhooklen   $ldelta $lasttxt $postdelta $lhooklen]
 				foreach {status firstnew ldeltanew} $new break
-				if {[string equal $status "LOSE"]} {
+				if {$status eq "LOSE"} {
 					incr stat(high-lose)
 					append losertxt "[string range $firsttxt 0 [expr {$predelta-1}]] / [string range $firsttxt $predelta end] ($first)   ...   [string range $lasttxt 0 [expr {[string length $lasttxt]-$postdelta}]] / [string range $lasttxt [expr {[string length $lasttxt]-$postdelta+1}] end] (+$ldelta)\n"
 					append res ", lost one"
@@ -151,7 +145,7 @@ proc manHighlights {w {cmd update} {auto 0}} {
 					incr stat(high-move)
 					eval lappend newtags [manHighCompose $t $firstnew "$firstnew+${ldeltanew}c"]
 					# dicey move
-					if {[string equal $status "DICEY"]} { set dicey 1; append res ", dicey move" }
+					if {$status eq "DICEY"} { set dicey 1; append res ", dicey move" }
 				} else {
 					incr stat(high-exact)
 					# old info is still good
@@ -163,14 +157,14 @@ proc manHighlights {w {cmd update} {auto 0}} {
 			set warningtxt ""
 
 			# report losers at bottom
-			if {![string equal $losertxt ""]} {
+			if {$losertxt ne ""} {
 				manTextPlug $t end "\n\n\nCouldn't attach these highlights:\n" b $losertxt {} "\n"
 				append warningtxt "Some highlights could not be repositioned.  See the bottom of the page for a list.  They will be forgotten unless they are reapplied manually now.   "
 			}
 			if {$dicey} {
 				append warningtxt "Some highlights have moved considerably and may not have been repositioned correctly.  You may want to verify them now.   "
 			}
-			if {![string equal $warningtxt ""] && !$auto} {
+			if {$warningtxt ne "" && !$auto} {
 				tk_messageBox -title "Warning" -message $warningtxt -icon warning -type ok
 			}
 
@@ -186,7 +180,7 @@ proc manHighlights {w {cmd update} {auto 0}} {
 				append res ", OK"
 			} else {
 				# old style highlights lose
-				if {!$auto && [string equal [tk_messageBox -title "Warning" -message "Highlights out of date for $f.  Delete them?" -icon question -type yesno] "no"]} {
+				if {!$auto && [tk_messageBox -title "Warning" -message "Highlights out of date for $f.  Delete them?" -icon question -type yesno] eq "no"} {
 					set $var [set tags "[file mtime $f] [lrange [set $var] 1 end]"]
 				}
 				append res ", out of date"
@@ -218,7 +212,7 @@ proc manHighlights {w {cmd update} {auto 0}} {
 		$t tag add highlight $first $last
 
 		# show likely relevant information
-		if {$manx(tryoutline$w) && ![string equal $man(highlight-show) "never"]} {nb $t $man(highlight-show) $first $last}
+		if {$manx(tryoutline$w) && $man(highlight-show) ne "never"} {nb $t $man(highlight-show) $first $last}
 
 		if {$auto} { $t yview -pickplace $last; update idletasks; after 1000 }
 		set label \
@@ -229,7 +223,7 @@ proc manHighlights {w {cmd update} {auto 0}} {
 	manShowTagDist $w highlight 3
 
 	# propagate highlight information to section headers, if highlights not always visible
-	if {$manx(tryoutline$w) && ![string equal $man(highlight-show) "halwaysvis"]} {
+	if {$manx(tryoutline$w) && $man(highlight-show) ne "halwaysvis"} {
 #($manx(subsect-show) => always for man, never for Texinfo
 		foreach now $manx(sectposns$w) next $manx(nextposns$w) {
 			if {[$t tag nextrange highlight $now $next-1l]!=""} {
@@ -394,13 +388,13 @@ proc manHighlightAttach {t first firsttxt predelta fhooklen  ldelta lasttxt post
 	# Tk doesn't search across lines!
 	set ffw [$t search -forwards -regexp $viz $fregexp $first end]
 	set fbk [$t search -backwards -regexp $viz $fregexp $first 1.0]
-	if {[string equal $ffw ""] && [string equal $fbk ""]} {
+	if {$ffw eq "" && $fbk eq ""} {
 		# nothing yet
-	} elseif {[string equal $ffw ""]} {
+	} elseif {$ffw eq ""} {
 		set fpt $fbk
 		set found 1
 		DEBUG {puts "only found backward from $first at $fbk"}
-	} elseif {[string equal $fbk ""]} {
+	} elseif {$fbk eq ""} {
 		set fpt $ffw
 		set found 1
 		DEBUG {puts "only found foward from $first at $ffw"}
@@ -467,13 +461,13 @@ proc manHighlightAttach {t first firsttxt predelta fhooklen  ldelta lasttxt post
 #puts "searching backward for $lregexp"
 	set lfw [$t search -forwards -regexp -count lfwcnt $viz $lregexp $last end]
 	set lbk [$t search -backwards -regexp -count lbkcnt $viz $lregexp $last $fpt]
-	if {[string equal $lfw ""] && [string equal $lbk ""]} {
-	} elseif {[string equal $lfw ""]} {
+	if {$lfw eq "" && $lbk eq ""} {
+	} elseif {$lfw eq ""} {
 		set lpt $lbk
 		set llen $lbkcnt
 		set found 1
 		DEBUG {puts "end only found backward from $fpt at $lbk"}
-	} elseif {[string equal $lbk ""]} {
+	} elseif {$lbk eq ""} {
 		set lpt $lfw
 		set llen $lfwcnt
 		set found 1
