@@ -4,13 +4,12 @@
 #
 #--------------------------------------------------
 
-# would like to generalize construction, but can't spare the time
 proc manPreferencesMake {{w0 ""}} {
 	global prefedit manx man bozo
 # don't do global man here
 
 	set w .prefs
-	if {[winfo exists $w]||[string equal $w0 ""]} {return $w}
+	if {[winfo exists $w] || $w0 eq ""} {return $w}
 
 	toplevel $w; wm resizable $w 0 0
 	wm geometry $w $prefedit(geom-prefs)
@@ -75,7 +74,7 @@ proc manPreferencesMake {{w0 ""}} {
 		label $f.l -text $txt
 		foreach j {{fg "foreground"} {bg "background"}} {
 			foreach {jvar jtxt} $j break
-			if {[string equal $jvar "fg"]} {set jopp "bg"} else {set jopp "fg"}
+			if {$jvar eq "fg"} {set jopp "bg"} else {set jopp "fg"}
 			set mb $f.$var$jvar
 			[set m [eval tk_optionMenu $mb prefedit($var$jvar) $man(colors)]] configure -tearoff no
 			# when monochrome, keep foreground and background colors opposites!
@@ -103,7 +102,7 @@ proc manPreferencesMake {{w0 ""}} {
 		[set m [eval tk_optionMenu [set mb $f.$var] prefedit($var) $manx(highs)]] configure -tearoff no
 			foreach k $manx(highs) {
 				if {[lsearch $man(colors) $k]==-1} {set val $k} \
-				else {if {[string equal $fb "f"]} { set val "-foreground [list $k]"} else { set val "-background [list $k]" } }
+				else {if {$fb eq "f"} { set val "-foreground [list $k]"} else { set val "-background [list $k]" } }
 				$m entryconfigure $k -command "set prefedit($var) [list $val]"
 			}
 		pack $f.l -side left -fill x
@@ -131,7 +130,7 @@ proc manPreferencesMake {{w0 ""}} {
 			subvols "Subvolumes as submenus in Volumes"
 			apropostab "Tab stop in apropos list"
 			rebus "Rebus (icons instead of words) for: file, TeX, ..."
-			lengthchunk "Page length reported in (estimated)"
+			lengthchunk "Page length (estimated) reported in"
 #			diffbar "Generate change bars"
 		} {
 		lappend manx(vars-$group) $var
@@ -293,7 +292,7 @@ proc manPreferencesMake {{w0 ""}} {
 	}
 
 
-	if {![string equal $man(print) ""]} {
+	if {$man(print) ne ""} {
 		foreach {var txt} {printers "Printer list (space separated)"} {
 			lappend manx(vars-$group) $var
 
@@ -437,11 +436,11 @@ proc manPreferences {{screen ""}} {
 	# show right grouping
 	set w [manPreferencesMake bozo]
 	raise $w
-	if {[string equal $screen ""]} {set screen $manx(prefscreen)} else {set manx(prefscreen) $screen}
+	if {$screen eq ""} {set screen $manx(prefscreen)} else {set manx(prefscreen) $screen}
 	set prev $manx(oldprefscreen)
 
-	if {![string equal $screen $prev]} {
-		if {![string equal $prev ""]} {
+	if {$screen ne $prev} {
+		if {$prev ne ""} {
 			pack forget $w.$prev
 #			$w.pages.$prev configure -relief raised
 		}
@@ -509,7 +508,7 @@ proc manPreferencesSet {} {
 
 	set change 0
 	foreach i [array names default] {
-		if {![string equal $curedit($i) $prefedit($i)]} {
+		if {$curedit($i) ne $prefedit($i)} {
 			set change 1
 			break
 		}
@@ -547,7 +546,7 @@ proc manPreferencesSetGlobal {} {
 	# icon-related
 	# ... need to reference man() to get new values, but manx() has command line options
 	foreach i {iconname iconposition iconbitmap iconmask} {
-		if {![string equal $man($i) $curedit($i)]} {set manx($i) $man($i)}
+		if {$man($i) ne $curedit($i)} {set manx($i) $man($i)}
 	}
 
 	manShortcuts .man init
@@ -555,7 +554,7 @@ proc manPreferencesSetGlobal {} {
 	set manx(effcols) ""
 	if {[string match "*groff*$manx(longtmp) -*" $man(format)] && $man(columns)!=65} {set manx(effcols) "@$man(columns)"}
 
-	if {![string equal $man(print) ""] && ([string equal [[set m2 .occ.kill] index end] "none"] || ![string equal $curedit(printers) $man(printers)]) } {
+	if {$man(print) ne "" && ([[set m2 .occ.kill] index end] eq "none" || $curedit(printers) ne $man(printers)) } {
 		set plist [string trim $man(printers)]
 		# always put default printer in list
 		if {[lsearch $plist $manx(printer)]==-1} {set plist [concat $manx(printer) $plist]}
@@ -566,15 +565,15 @@ proc manPreferencesSetGlobal {} {
 		if {![llength $plist]} {$m2 add command -label "(default)" -command "manPrint \$curwin"}
 	}
 
-	if {![string equal $curedit(subvols) $man(subvols)]} {manMakeVolList 1}
+	if {$curedit(subvols) ne $man(subvols)} {manMakeVolList 1}
 
 	# update text tags and other .man* bits
 	foreach w [lmatches ".man*" [winfo children .]] {manPreferencesSetMain $w}
 
 	foreach w [lmatches ".man*" [winfo children .]] {
-		foreach i {info kind mantypein} {bind $w.$i <Enter> [expr $man(focus)?"focus $w.mantypein":""]}
-		foreach i {vf show v} {bind $w.$i <Enter> [expr $man(focus)?"focus $w.show":""]}
-		bind $w.search <Enter> [expr $man(focus)?"focus $w.search.t":""]
+		foreach i {info kind mantypein} {bind $w.$i <Enter> [expr {$man(focus)?"focus $w.mantypein":""}]}
+		foreach i {vf show v} {bind $w.$i <Enter> [expr {$man(focus)?"focus $w.show":""}]}
+		bind $w.search <Enter> [expr {$man(focus)?"focus $w.search.t":""}]
 	}
 
 
@@ -618,7 +617,7 @@ proc manPreferencesSetMain {w} {
 		# everybody shares same icons
 		# (null string for name means no icon)
 		foreach i {iconbitmap iconmask} {
-			if {![string equal $manx($i) ""]} {
+			if {$manx($i) ne ""} {
 				if {[catch {wm $i $w @$manx($i)} info]} {
 					puts stderr "Bad $i: $manx($i).  Fix in Preferences/Icon."
 #					tk_dialog .dialog "BAD [string toupper $i]" "Bad $i: $manx($i).  Fix in Preferences/Icon." "" 0 " OK "
@@ -643,7 +642,7 @@ proc manPreferencesSetMain {w} {
 		lower $w.top; raise $w.info
 		bind $w.mantypein <FocusIn> "lower $w.info"
 		bind $w.info <Motion> "lower $w.info"
-		bind $t <Motion> "+if {%y>\[winfo height $t]-[winfo reqheight $w.search]} {place $w.search -x 0}"
+		bind $t <Motion> "+if {%y > \[winfo height $t]-[winfo reqheight $w.search]} {place $w.search -x 0}"
 		place $w.search -in $t -x -[winfo width $t] -rely 1 -y -[winfo reqheight $w.search] -relwidth 1
 		bind $w.search.t <FocusIn> "place $w.search -in $t -x 0"
 		bind $w.search.t <FocusOut> "place $w.search -x -\[winfo width $t]"
@@ -663,7 +662,7 @@ proc manPreferencesSetMain {w} {
 
 	# the scrollbar is an oddball
 	$w.v configure -troughcolor $man(guibg)
-	$w.v configure -background [expr {![string equal $man(buttbg) $man(guibg)]?$man(buttbg):$man(guibg)}]
+	$w.v configure -background [expr {$man(buttbg) ne $man(guibg)? $man(buttbg) : $man(guibg)}]
 
 	# text widget fonts and tags
 	$t configure -padx $man(textboxmargin) -pady $man(textboxmargin)
@@ -726,10 +725,10 @@ proc manPreferencesSetMain {w} {
 		}
 		if {$newfont} {append change " -font \"[spec2font $fam $sty $poi $poi2]\""}
 #puts "change $v = $change"
-		if {![string equal $change ""]} {
+		if {$change ne ""} {
 			eval $t tag configure $v $change
-			if {[string equal $v "highlight"]} {catch {eval $w.high configure $change}}
-#			if {[string equal $v "search"]} {catch {eval $w.search.s configure $change}}
+			if {$v eq "highlight"} {catch {eval $w.high configure $change}}
+#			if {$v eq "search"} {catch {eval $w.search.s configure $change}}
 		}
 	}
 	$t tag raise sel
@@ -745,7 +744,7 @@ proc manPreferencesSetMain {w} {
 	if {$man(showrandom)} {pack $w.random -before $w.vols -side left -padx 10} else {pack forget $w.random}
 
 
-	if {![string equal $curedit(hyperclick) $man(hyperclick)]} {manHyper $w ""}
+	if {$curedit(hyperclick) ne $man(hyperclick)} {manHyper $w ""}
 }
 
 
@@ -753,8 +752,8 @@ proc resetcolors {{w .}} {
 	global man curedit
 
 	set c [winfo class $w]
-	set g "gui"; if {[string equal $c "Text"]} {set g "text"} elseif {[string match "*utton" $c]} {set g "butt"}
-#||[string equal $c "Entry"]
+	set g "gui"; if {$c eq "Text"} {set g "text"} elseif {[string match "*utton" $c]} {set g "butt"}
+#|| $c eq "Entry"
 	set foreground [set selector [set insertbackground $man(${g}fg)]]
 	set background $man(${g}bg)
 	set ofg $curedit(${g}fg)
@@ -763,8 +762,8 @@ proc resetcolors {{w .}} {
 #puts "checking $w, class $c"
 	foreach i {foreground background insertbackground selectcolor} {
 		if {![catch {set color [$w cget -$i]}]} {
-			 if {[string equal $color $ofg]} {$w configure -$i $foreground} \
-			 elseif {[string equal $color $obg]} {$w configure -$i $background}
+			 if {$color eq $ofg} {$w configure -$i $foreground} \
+			 elseif {$color eq $obg} {$w configure -$i $background}
 		}
 	}
 
