@@ -14,7 +14,7 @@ if {$cnt==1} {
 	# if multiple instantiations, find one on same machine
 	set hostname [info hostname]
 	foreach man $tkmen {
-		if {[string equal [send $man info hostname] $hostname]} {
+		if {[send $man info hostname] eq $hostname} {
 			catch {send $man "manSave; exit 0"}
 			break
 		}
