@@ -1,14 +1,13 @@
-# $Header: /home/orodruin/h/bair/phelps/spine/sb/RCS/searchbox.tcl,v 1.22 1997/08/11 19:01:20 phelps Exp phelps $
-
 #
 # SearchBox mega widget
 #   incremental and regular expression searching in a text widget
 #   for examples of use, see TkMan and tkinfo
 #
-#   Copyright (C) 1993-1999  Thomas A. Phelps (phelps@ACM.org)
+#   Copyright (C) 1993-2003 Tom Phelps (phelps@ACM.org)
 #
 # extracted from TkMan, and then used by TkMan and NBT 6-Aug-93
 #
+# 1993
 # 19-Aug  made more robust (Kennard White)
 #
 # 1994
@@ -23,6 +22,10 @@
 # 1996
 #  6-Feb  Tk 4.1 can search for tags backward
 #  3-Jun  wraparound behavior gives warnings (Rick Macdonald)
+#
+# 2003
+# 14-Mar  updated for Tcl/Tk 8.4 (now requires Tcl/Tk 8.4)
+
 
 # name space use: prefixes searchbox, sb, sbx
 # does NOT require taputils.tcl
@@ -95,16 +98,6 @@ foreach e [array names sb] {
 }
 
 
-### environment checks
-if {[info tclversion]<7.4 || $tk_version<4.0} {
-	puts stderr "Tcl 7.4/Tk 4.0 minimum versions required"
-	puts stderr "You have Tcl [info tclversion]/Tk $tk_version"
-	exit 1
-}
-
-
-
-
 #--------------------------------------------------
 #
 # searchboxSearch -- initiate an exact or regular expression search
@@ -125,28 +118,30 @@ if {[info tclversion]<7.4 || $tk_version<4.0} {
 proc searchboxSearch {pat regexp casesen tag t {wmsg ""} {wcnt ""} args} {
 	global sbx
 
-	if {$args=="{}"} {set args ""}
+	if {$args eq "{}"} {set args ""}
 
-	if {$casesen==-1} {set casesen [expr {[string tolower $pat]!=$pat}]}
-	set caseopt [expr {!$casesen?"-nocase":""}]
-	set type [expr {$regexp?"regexp":"exact"}]; # make into string to pass back to Tcl
+	if {$casesen==-1} {set casesen ![string is lower $pat]}
+	set caseopt [expr !$casesen?"-nocase":""]
+	if {$regexp} {set type "regexp"} {set type "exact"}
 
-	if {$pat==""} {
-		winstderr $wmsg "Nothing to search for!  Type in a [expr {$regexp?{regular expression}:{string}}]."
+	if {$pat eq ""} {
+		winstderr $wmsg "Nothing to search for!  Type in a [expr $regexp?{regular expression}:{string}]."
 		return 0
 	}
 
 
 	# check for bad regular expression
-	if {![string match "TAG:*" $pat] && $type=="regexp" && ([catch {regexp $pat bozomaniac}] || [regexp $pat ""])} {
+	if {![string match "TAG:*" $pat] && $type eq "regexp" && [catch {regexp $pat bozomaniac}]} {
 		winstderr $wmsg "Malformed regular expression."
 		return 0
 	}
 
 	$t tag remove $tag 1.0 end
 
+	# wow, heaps faster with Tk 4.0's built-in searching
 	set cnt 0
 
+
 	if {[regexp "^TAG:(.*)" $pat all ptag]} {
 		$t tag remove $tag 1.0 end
 		set cnt 0
@@ -159,7 +154,7 @@ proc searchboxSearch {pat regexp casesen tag t {wmsg ""} {wcnt ""} args} {
 	} else {
 		set index 1.0
 		set len 0
-		while {[set index [eval "$t search -forwards -$type $caseopt $args -count len -- {$pat} {$index+$len chars} end"]]!=""} {
+		while {[set index [eval "$t search -forwards -$type $caseopt $args -count len -- {$pat} {$index+$len chars} end"]] ne ""} {
 			$t tag add $tag $index "$index + $len chars"
 			incr cnt
 		}
@@ -168,7 +163,7 @@ proc searchboxSearch {pat regexp casesen tag t {wmsg ""} {wcnt ""} args} {
 
 	if {$cnt==0} {set txt "no matches"} else {set txt "$cnt [textmanip::plural $cnt match es]"}
 #	winstdout $wcnt $txt
-	if {$wcnt!=""} {$wcnt configure -text $txt}
+	if {$wcnt ne ""} {$wcnt configure -text $txt}
 
 	# show the first match
 	set sbx(ratend$t) 0; set sbx(ratstart$t) 0
@@ -194,21 +189,21 @@ proc searchboxSearch {pat regexp casesen tag t {wmsg ""} {wcnt ""} args} {
 proc searchboxNext {tag t {wmsg ""} {yoff ""}} {
 	global sbx
 
-	if {[$t tag ranges $tag]==""} { winstderr $wmsg "No matches!"; return }
+	if {![llength [$t tag ranges $tag]]} { winstderr $wmsg "No matches!"; return }
 
-	if {$yoff==""} {
+	if {$yoff eq ""} {
 		set yoff [winfo height $t]; set start [$t index @0,$yoff]
 #puts "prevrange = [$t tag prevrange search @0,$yoff @0,0]"
 		if {[set prev [$t tag prevrange search @0,$yoff @0,0]]!=""} {set start [$t index [lsecond $prev]+1c]}
 	} else { set start [$t index @0,$yoff] }
 	set hit [$t tag nextrange $tag $start]
-	if {$hit==""} {
+	if {$hit eq ""} {
 		if {$sbx(ratend$t)} {
 			set hit [$t tag nextrange $tag 1.0]
 			set sbx(ratend$t) 0
 		} else {
 			set sbx(ratend$t) 1
-			if {[$t bbox 1.0]==""} {winstderr $wmsg $sbx(wrap-msg)} else {searchboxNext $tag $t $wmsg $yoff}
+			if {[$t bbox 1.0] eq ""} {winstderr $wmsg $sbx(wrap-msg)} {searchboxNext $tag $t $wmsg $yoff}
 		}
 	}
 	if {$hit!=""} {
@@ -222,16 +217,16 @@ proc searchboxNext {tag t {wmsg ""} {yoff ""}} {
 proc searchboxPrev {tag t {wmsg ""}} {
 	global sbx
 
-	if {[$t tag ranges $tag]==""} { winstderr $wmsg "No matches!"; return }
+	if {![llength [$t tag ranges $tag]]} { winstderr $wmsg "No matches!"; return }
 
 	set hit [$t tag prevrange $tag [$t index @0,0]]
-	if {$hit==""} {
+	if {$hit eq ""} {
 		if {$sbx(ratstart$t)} {
 			set hit [$t tag prevrange $tag end]
 			set sbx(ratstart$t) 0
 		} else {
 			set sbx(ratstart$t) 1
-			if {[$t bbox end-1c]==""} {winstderr $wmsg $sbx(wrap-msg)} else {searchboxPrev $tag $t $wmsg}
+			if {[$t bbox end-1c] eq ""} {winstderr $wmsg $sbx(wrap-msg)} {searchboxPrev $tag $t $wmsg}
 		}
 	}
 
@@ -264,7 +259,7 @@ proc searchboxKeyNav {m k casesen t {wmsg ""} {firstmode 0} args} {
 #puts "$m $k $casesen $t $wmsg $firstmode"
 	global sb sbx
 
-	if {$args=="{}"} {set args ""}
+	if {$args eq "{}"} {set args ""}
 
 	if {[regexp {(Shift|Control|Meta|Alt|NunLock)_.} $k]} {return 0}
 	if {![info exists sbx(try$t)]} {
@@ -273,33 +268,33 @@ proc searchboxKeyNav {m k casesen t {wmsg ""} {firstmode 0} args} {
 		set sbx(lastkeys$t) ""
 		set sbx(iatstart$t) 0; set sbx(iatend$t) 0
 		# other apps may wish to seed default search string
-		if {![info exists sbx(lastkeys-old$t)]} {set sbx(lastkeys-old$t) ""}
+		if ![info exists sbx(lastkeys-old$t)] {set sbx(lastkeys-old$t) ""}
 	}
 
 
 	# some translations
-	if {!$firstmode && ($sbx(try$t) || $sbx(lastkeys$t)!="")} {
+	if {!$firstmode && ($sbx(try$t) || $sbx(lastkeys$t) ne "")} {
 		switch -exact -- $k {
 			space {set k " "}
 			BackSpace -
 			Delete {
 				set k ""
-				set last [expr {[string length $sbx(lastkeys$t)]-2}]
+				set last [expr [string length $sbx(lastkeys$t)]-2]
 				set sbx(lastkeys$t) [string range $sbx(lastkeys$t) 0 $last]
 				set sbx(try$t) 1
 			}
-			default { if {$m==""||$m=="S"} {set k [name2char $k]} }
+			default { if {$m eq "" || $m eq "S"} {set k [name2char $k]} }
 		}
 	}
 
 
 	# commands
-	set m [string trimright $m "S"]; # strip shift as a modifier
+	set m [string trimright $m "SM"]; # strip shift and numlock as a modifier
 	set mk $m-$k
 #puts "searchbox: mk = $mk"
-	if {$m=="literal"} {set op $k} \
+	if {$m eq "literal"} {set op $k} \
 	elseif {[info exists sb(key,$mk)]} {set op $sb(key,$mk)} \
-	elseif {$m=="" && [string length $k]<=1} {set op default} \
+	elseif {$m eq "" && [string length $k]<=1} {set op default} \
 	else {return 0}
 
 #puts stdout "trying for a match on $mk"
@@ -320,7 +315,7 @@ proc searchboxKeyNav {m k casesen t {wmsg ""} {firstmode 0} args} {
 		pageend {$t yview moveto 1}
 		searchkill {
 #puts stderr "killing search"
-			if {$sbx(lastkeys$t)!=""} {set sbx(lastkeys-old$t) $sbx(lastkeys$t)}
+			if {$sbx(lastkeys$t) ne ""} {set sbx(lastkeys-old$t) $sbx(lastkeys$t)}
 			set sbx(lastkeys$t) ""; set sbx(try$t) 0
 			winstdout $wmsg ""
 		}
@@ -330,14 +325,14 @@ proc searchboxKeyNav {m k casesen t {wmsg ""} {firstmode 0} args} {
 		default {
 #puts stderr "incr search...  op=$op"
 			# incremental search
-			if {$op=="incrsearch"} {
+			if {$op eq "incrsearch"} {
 				# C-s C-s retrieves last search pattern
-				if {$sbx(try$t)&&$sbx(lastkeys$t)==""} {set sbx(lastkeys$t) $sbx(lastkeys-old$t)}
-#				if {$sbx(lastkeys$t)==""} {$t tag remove isearch 1.0 end}
+				if {$sbx(try$t) && $sbx(lastkeys$t) eq ""} {set sbx(lastkeys$t) $sbx(lastkeys-old$t)}
+#				if {$sbx(lastkeys$t) eq ""} {$t tag remove isearch 1.0 end}
 				set sbx(vect$t) 1; set sbx(try$t) 1
-			} elseif {$op=="revincrsearch"} {
-				if {$sbx(try$t)&&$sbx(lastkeys$t)==""} {set sbx(lastkeys$t) $sbx(lastkeys-old$t)}
-#				if {$sbx(lastkeys$t)==""} {$t tag remove isearch 1.0 end}
+			} elseif {$op eq "revincrsearch"} {
+				if {$sbx(try$t) && $sbx(lastkeys$t) eq ""} {set sbx(lastkeys$t) $sbx(lastkeys-old$t)}
+#				if {$sbx(lastkeys$t) eq ""} {$t tag remove isearch 1.0 end}
 				set sbx(vect$t) -1; set sbx(try$t) 1
 			} elseif {$firstmode} {
 #				$t tag remove isearch 1.0 end
@@ -348,18 +343,18 @@ proc searchboxKeyNav {m k casesen t {wmsg ""} {firstmode 0} args} {
 			}
 
 			set keys $sbx(lastkeys$t)
-			if {$casesen==-1} {set casesen [expr {[string tolower $keys]!=$keys}]}
-			set caseopt [expr {!$casesen?"-nocase":""}]
-			if {$sbx(try$t)==0 && $keys==""} {return 0}
+			if {$casesen==-1} {set casesen ![string is lower $keys]}
+			set caseopt [expr !$casesen?"-nocase":""]
+			if {$sbx(try$t)==0 && $keys eq ""} {return 0}
 			winstdout $wmsg "Searching for \"$keys\" ..."
-#			if {$sbx(try$t)==0 || $keys==""} {return 1}
+#			if {$sbx(try$t)==0 || $keys eq ""} {return 1}
 
 
 			if {$firstmode} {
 				set start 1.0; set end end
-			} elseif {[set ranges [$t tag ranges isearch]]!=""} {
+			} elseif {[llength [set ranges [$t tag ranges isearch]]]} {
 				set start [lindex $ranges 0]; set end 1.0
-				if {$op=="incrsearch"} {set start [$t index "$start+1c"]}
+				if {$op eq "incrsearch"} {set start [$t index "$start+1c"]}
 				if {$sbx(vect$t)==1} {set end "end"}
 			} else {
 				if {$sbx(vect$t)==1} {
@@ -371,8 +366,8 @@ proc searchboxKeyNav {m k casesen t {wmsg ""} {firstmode 0} args} {
 
 			# need case sensitive switch here
 			set dir [expr {$sbx(vect$t)==1?"-forwards":"-backwards"}]
-			set type [expr {$firstmode?"-regexp":"-exact"}]
-			set pfx [expr {$firstmode?"^":""}]
+			set type [expr $firstmode?"-regexp":"-exact"]
+			set pfx [expr $firstmode?"^":""]
 			set search "$t search $dir $type $caseopt -count klen $args -- [list $pfx$keys] $start"
 #DEBUG {puts "$search ... $end"}
 			set found [eval "$search $end"]
@@ -381,8 +376,8 @@ proc searchboxKeyNav {m k casesen t {wmsg ""} {firstmode 0} args} {
 #puts "$op... $t search $dir $type $caseopt -count klen -- {$pfx$keys} $start"
 
 			# wraparound behavior
-			if {$anywhere!=""} {
-				if {$found!=""} {
+			if {$anywhere ne ""} {
+				if {$found ne ""} {
 					$t tag remove isearch 1.0 end
 					$t tag add isearch $found "$found + $klen c"
 					$t mark set hit $found
@@ -434,7 +429,7 @@ proc searchboxSaveConfig {fid} {
 	puts $fid "#\n# SearchBox\n#\n"
 	foreach i [lsort [array names sb]] {
 		set co ""
-		if {[info exists sbdef($i)] && $sbdef($i)==$sb($i)} {set co "#"}
+		if {[info exists sbdef($i)] && $sbdef($i) eq $sb($i)} {set co "#"}
 		puts $fid "${co}set sb($i) [list $sb($i)]"
 	}
 	puts $fid "\n"
@@ -443,7 +438,7 @@ proc searchboxSaveConfig {fid} {
 
 
 # instantiate standard mechanisms if don't already exist
-if {[info procs winstdout]==""} {
+if {![llength [info procs winstdout]]} {
 
 proc winstderr {w msg {type "bell & flash"}} {
 	if {![winfo exists $w]} return
@@ -468,7 +463,7 @@ proc winstderr {w msg {type "bell & flash"}} {
 
 proc winstdout {w {msg AnUnLiKeMeSsAgE} {update 0}} {
 	if {![winfo exists $w]} return
-	if {$msg!="AnUnLiKeMeSsAgE"} {
+	if {$msg ne "AnUnLiKeMeSsAgE"} {
 		$w configure -text $msg
 		if {$update} { update idletasks }
 	}
