@@ -47,8 +47,8 @@ proc manStatistics {w} {
 			foreach point $man(chronobrowse) {
 				foreach {time counts} [split $point ":"] break
 				foreach {start duration reading} [split $time "/"] break
-				if {[string equal $duration ""]} {set duration 0}
-				if {[string equal $reading ""]} {set reading 0}
+				if {$duration eq ""} {set duration 0}
+				if {$reading eq ""} {set reading 0}
 				foreach {mancnt texcnt rfccnt} [split $counts "/"] break
 
 				set day [clock format $start -format "%a"]
@@ -83,7 +83,7 @@ proc manStatistics {w} {
 
 	foreach i $manx(modes) desc $manx(mode-desc) {
 		$t insert end "$stat($i)\t$desc " "" "\[$stat(cum-$i)\]\n" i
-		if {[string equal $i "man"]} {
+		if {$i eq "man"} {
 # && $stat(man)} {
 #			if $stat(man-no) {
 				$t delete end-1c
@@ -130,7 +130,7 @@ proc manStatistics {w} {
 
 	$t insert end "$stat(print)\tpages printed  " "" "\[$stat(cum-print)\]\n" i
 
-	if {![string equal $man(glimpse) ""]} {$t insert end "$stat(glimpse-builds)\tGlimpse index builds  " "" "\[$stat(cum-glimpse-builds)\]\n" i}
+	if {$man(glimpse) ne ""} {$t insert end "$stat(glimpse-builds)\tGlimpse index builds  " "" "\[$stat(cum-glimpse-builds)\]\n" i}
 
 
 	global tk_patchLevel
@@ -146,9 +146,9 @@ proc manStatistics {w} {
 		$t insert end "\nVariables overridden in [bolg $manx(startup) ~]\n\n" h1
 		set allold 1
 		foreach i [lsort [array names default]] {
-			set new [tr $man($i) \n " "]; if {[string equal $new ""]} {set new "(null)"}
-			set old [tr $default($i) \n " "]; if {[string equal $old ""]} {set old "(null)"}
-			if {![string equal $new $old]} {
+			set new [tr $man($i) \n " "]; if {$new eq ""} {set new "(null)"}
+			set old [tr $default($i) \n " "]; if {$old eq ""} {set old "(null)"}
+			if {$new ne $old} {
 				$t insert end "man(" {} $i b ") = " {} $new tt ", " {} "formerly " i $old tt "\n"
 				set allold 0
 			}
@@ -184,8 +184,8 @@ proc manStatistics {w} {
 		$t insert end "Startup " b "file last save\n\t" {} $manx(startup) tt "\t" {} [textmanip::recently [file mtime $manx(startup)]] i "\n"
 	}
 	# iterate through all glimpse directories?
-	if {![string equal $man(glimpse) ""]} {
-		if {[string equal $man(indexglimpse) "distributed"]} {
+	if {$man(glimpse) ne ""} {
+		if {$man(indexglimpse) eq "distributed"} {
 			$t insert end "Distributed Glimpse " {} "indexes" b " latest updates\n"
 			set paths $manx(paths)
 		} else { 
@@ -208,7 +208,7 @@ proc manStatistics {w} {
 
 	set manpath0 [join $manx(paths) ":"]
 	$t insert end "MANPATH" sc ": " "" $manpath0 tt "\n"
-	if {![string equal $manx(MANPATH0) $manpath0]} {
+	if {$manx(MANPATH0) ne $manpath0} {
 		$t insert end "As cleaned up from original " "" "MANPATH" sc ": "
 		foreach path [split $manx(MANPATH0) ":"] {
 			$t insert end $path [expr {[lsearch -exact $manx(paths) $path]==-1?"i":"tt"}] ":" tt
@@ -288,9 +288,9 @@ proc manBug {w} {
 		$t insert end "\n\nVariables overridden in [bolg $manx(startup) ~]\n\n" h1
 		set allold 1
 		foreach i [lsort [array names default]] {
-			set new [tr $man($i) \n " "]; if {[string equal $new ""]} {set new "(null)"}
-			set old [tr $default($i) \n " "]; if {[string equal $old ""]} {set old "(null)"}
-			if {![string equal $new $old]} {
+			set new [tr $man($i) \n " "]; if {$new eq ""} {set new "(null)"}
+			set old [tr $default($i) \n " "]; if {$old eq ""} {set old "(null)"}
+			if {$new ne $old} {
 				$t insert end "man(" {} $i b ") = " {} $new code ", " {} "formerly " i $old code "\n"
 				set allold 0
 			}
