@@ -2,7 +2,7 @@
 
 #
 # GNU info *source* reader
-# 19 January 1997
+# 1997 January 19
 #
 # 1997
 # 19 Jan	basically works
@@ -23,20 +23,6 @@
 #
 
 # Pretends it's an info.  Would be better to pretend to be tex, but then get raw TeX commands.
-# non-spec tags seen in (bogus) use: @ichapter, @UNREVISED, @FIXME
-
-# to do:
-# for commands not handled, report when see one
-# random tags (r that overrides)
-# can merge tables and other regions, then can inline FindRegion
-# if no match on hyperlink try all lowercase (recover from author's sloppiness)
-# update for Texinfo 3.11 (image, deftypemethod, kbdinputstyle, ...)
-# could be slightly more efficient at markup time by making sure all @texiaccent are set so can handle in regsub and making sure no duplicates in index, but this is not a bottleneck
-# could have LRU throwing out of collapsed sections
-# fault in indexes in off cycles so don't have to wait so long when search first time
-# make regsub pass @=>\001 then \001\001=>@ so don't have pervasive complications from @'s?
-
-
 
 # find <l>...@end <l> in text widget, delete that text, return range of bracked text
 proc texiRegionFind {t l start end point} {
@@ -45,7 +31,7 @@ proc texiRegionFind {t l start end point} {
 	set ws {[ \t]}
 	# find first end to get innermost nested
 	set close [$t search -regexp -elide -- "^@end$ws+${l}($ws+|\$)" $point $end]
-	if {[string equal $close ""]} return
+	if {$close eq ""} return
 	set tag [$t get "$close+5c wordstart" "$close+5c wordend"]
 
 	# find corresponding start at same nesting level
@@ -53,8 +39,8 @@ proc texiRegionFind {t l start end point} {
 	set cnt -1
 	for {set open $close} {$cnt} {} {
 		set open [$t search -regexp -elide -backwards -count openlen -- $rx $open-1c $start]
-		if {[string equal $open ""]} return; # unmatched tags do happen
-		if {[string equal [$t get $open+1c $open+5c] "end "]} {incr cnt -1} else {incr cnt 1}
+		if {$open eq ""} return; # unmatched tags do happen
+		if {[$t get $open+1c $open+5c] eq "end "} {incr cnt -1} else {incr cnt 1}
 	}
 	set arg [$t get $open+${openlen}c "$open lineend"]
 
@@ -73,7 +59,7 @@ proc texiRevLineFindAll {t l start end} {
 #puts "[clock clicks]: texiLineFind $l"
 	set alllines {}
 	set rx "^@${l}( |\$)"
-	while {![string equal [set end [$t search -backwards -regexp -elide -count startlen -- $rx $end $start]] ""]} {
+	while {[set end [$t search -backwards -regexp -elide -count startlen -- $rx $end $start]] ne ""} {
 		#set tag [lindex [$t get $end+1c $end+${startlen}c-1c] 0]; #8.1 wordstart/wordend
 		set tag [$t get "$end+1c wordstart" "$end+1c wordend"]
 		$t delete $end $end+${startlen}c
@@ -91,20 +77,20 @@ proc texiTagFindAll {t l start end} {
 	set all {}
 
 	set orx "(^|@@|\[^@])@($l)\{"; set crx {[^@]@[a-z]+{|}}
-	while {![string equal [set open [$t search -regexp -elide -count openlen -- $orx $start $end]] ""]} {
+	while {[set open [$t search -regexp -elide -count openlen -- $orx $start $end]] ne ""} {
 		set opentxt [$t get $open $open+3c]
-		if {[string equal $opentxt "@@@"]} {append open "+2c"; incr openlen -2
-		} elseif {![string equal [string index $opentxt 0] "@"]} {append open "+1c"; incr openlen -1}
+		if {$opentxt eq "@@@"} {append open "+2c"; incr openlen -2
+		} elseif {[string index $opentxt 0] ne "@"} {append open "+1c"; incr openlen -1}
 		set openend "$open+${openlen}c"
 		set ocnt 1; set close $openend-1c
 		# handle nested braces
 		set closeadj ""
 		while {$ocnt} {
 			set newclose [$t search -regexp -elide -count insidelen -- $crx $close+1c $end]
-			if {[string equal $newclose ""]} break else {set close $newclose}
+			if {$newclose eq ""} break else {set close $newclose}
 			set t3 [$t get $close-2c $close+1c]
-			if {[string equal [string index $t3 2] "\}"]} {
-				if {![string equal [string index $t3 1] "@"] || [string equal [string index $t3 0] "@"]} {incr ocnt -1}
+			if {[string index $t3 2] eq "\}"} {
+				if {[string index $t3 1] ne "@" || [string index $t3 0] eq "@"} {incr ocnt -1}
 			} else {incr ocnt; append closeadj "-${insidelen}c-1c"}
 		}
 		if {$ocnt} break; # not properly nested
@@ -161,7 +147,7 @@ set texitrans(regexp) [join [array names texitrans] "|"]
 # maybe expand this with Tk 8.1's internationalization
 array set texiaccent {
 	`A "\xc0" 'A "\xc1" ^A "\xc2" ~A "\xc3" \"A "\xc4"
-	,-C "\xc7"
+	,C "\xc7"
 	`E "\xc8" 'E "\xc9" ^E "\xca" \"E "\xcb"
 	`I "\xcc" 'E "\xcd" ^I "\xce" \"I "\xcf"
 	barD "\xd0"
@@ -219,11 +205,11 @@ proc texiMarkup {t start end {force 0}} {
 				foreach tuple $texiindex($ctnt) {
 					foreach {iname isect ifont} $tuple break
 					set curletter [string tolower [string index $iname 0]]
-					if {[string equal $curletter $lastletter]} {
+					if {$curletter eq $lastletter} {
 						lappend txtindex "  " tt "/" "" "  " tt; incr icnt
 						# don't want icnt, but long lines don't scroll well and take enormously longer to format(!)
 						if {$icnt==10} {lappend txtindex "\n" ""; set icnt 0}
-					} elseif {![string equal $lastletter ""]} {lappend txtindex "\n\n " ""; set icnt 0}
+					} elseif {$lastletter ne ""} {lappend txtindex "\n\n " ""; set icnt 0}
 					lappend txtindex " $iname" [list texixref $ifont]
 					set lastletter $curletter
 				}
@@ -246,7 +232,7 @@ proc texiMarkup {t start end {force 0}} {
 			subtitle -
 			author -
 			center {
-				if {![string equal [$t get $s+1l] " "]} {$t insert $s+1l " "}
+				if {[$t get $s+1l] ne " "} {$t insert $s+1l " "}
 				$t insert $s " "; $t tag add $tag $s $s+1l
 			}
 		}
@@ -258,7 +244,7 @@ proc texiMarkup {t start end {force 0}} {
 	while 1 {
 		set tag ""
 		foreach {tag arg s e} [texiRegionFind $t {(quotation|display|example|smallexample|lisp|smalllisp|format|flushleft|flushright|def\S+)} $start $end $point] {set point $s}
-		if {[string equal $tag ""]} break
+		if {$tag eq ""} break
 
 		switch -glob $tag {
 			quotation {
@@ -268,19 +254,19 @@ proc texiMarkup {t start end {force 0}} {
 
 			def* {
 				# name, args left margin; category right margin; entered into index
-				if {[string match "def*index" $tag] || [string equal $tag "definfoenclose"]} continue
+				if {[string match "def*index" $tag] || $tag eq "definfoenclose"} continue
 				$t insert $s "\n"
 
 				while 1 {
 					set spec $texidef($tag)
 					set inx 0; set category [lsecond $texidef($tag)]
-					if {[string equal $category "category"]} {set category [lfirst $arg]; incr inx}
+					if {$category eq "category"} {set category [lfirst $arg]; incr inx}
 					$t insert $s " " {} [lindex $arg $inx] code "  " {} [lrange $arg [expr {1+$inx}] end] i "\t$category"
 					$t tag add rmtab $s "$s lineend"
 
 					# process def.*x
 					append s "+1l"
-					if {[string equal [$t get $s] "@"] && [string match "def*" [set tag [$t get $s+1c "$s+1c wordend-1c"]]]} {
+					if {[$t get $s] eq "@" && [string match "def*" [set tag [$t get $s+1c "$s+1c wordend-1c"]]]} {
 						set arg [$t get "$s+1c wordend+1c" "$s lineend"]
 						$t delete $s "$s lineend"
 					} else {$t insert $s " \t"; break}
@@ -291,13 +277,13 @@ proc texiMarkup {t start end {force 0}} {
 			# default = example|smallexample|lisp|smalllisp|format|flushleft|flushright
 			default {
 				# special markup with arg
-				if {[string match "flush*" $tag]} {set ichar " "} elseif {[string equal $tag "format"]} {set ichar " "; set tag "r"} else {set ichar " \t"}
+				if {[string match "flush*" $tag]} {set ichar " "} elseif {$tag eq "format"} {set ichar " "; set tag "r"} else {set ichar " \t"}
 				for {scan $e "%d" i; incr i -1} {$i>=$s} {incr i -1} {
 					$t insert $i.0 $ichar; # can't add $tag here too because want to pick up ALL existing tags
 #					$t tag add $tag $i.0
 				}
 				$t tag add $tag $s $e
-				if {![string equal [$t get $e] "\n"]} {$t insert $e "\n"}
+				if {[$t get $e] ne "\n"} {$t insert $e "\n"}
 			}
 		}
 	}
@@ -308,7 +294,7 @@ proc texiMarkup {t start end {force 0}} {
 	while 1 {
 		set tag ""
 		foreach {tag type s e} [texiRegionFind $t "(.?table|multitable|itemize|enumerate)" $start $end $point] {set point $s}
-		if {[string equal $tag ""]} break
+		if {$tag eq ""} break
 
 		set mt [string equal $tag "multitable"]; if {[string match "*table" $tag]} {set tag "table"}
 		set tabtag "list"
@@ -317,7 +303,7 @@ proc texiMarkup {t start end {force 0}} {
 			set mttabs ""
 			# collect @columnfractions or prototype row, if any
 			set scrnw [expr {[winfo width $t]-20}]
-			if {[string equal [lfirst $type] "@columnfractions"]} {
+			if {[lfirst $type] eq "@columnfractions"} {
 				# could check that each $fract<=1.0 and sum over $fract <=1.0, but not my problem
 				foreach fract [lrange $type 1 end] {lappend mttabs "[expr {int($scrnw*$fract)}]p"}
 			} else {
@@ -332,16 +318,16 @@ proc texiMarkup {t start end {force 0}} {
 			}
 			$t tag configure $tabtag -tabs $mttabs
 #puts "\atabs $mttabs"
-		} elseif {[string equal $tag "table"]} {
+		} elseif {$tag eq "table"} {
 			set tabtag "table"
 
-		} elseif {[string equal $tag "itemize"]} {
+		} elseif {$tag eq "itemize"} {
 			switch -glob -- $type {
 				@bullet* {set mark " \xb7\t"}
 				@minus* {set mark " -\t"}
 				default {set mark " $type"}
 			}
-		} elseif {[string equal $tag "enumerate"]} {
+		} elseif {$tag eq "enumerate"} {
 			set icnt 1
 			set format " %d.\t"
 			if {[regexp {\d+} $type num]} {set icnt $num} \
@@ -354,23 +340,23 @@ proc texiMarkup {t start end {force 0}} {
 #puts "$i<$ie   [$t get $i.0 [list $i.0 lineend]]"
 			# replace @item, @itemx by @table's argument
 			set linetag [$t get $i.0 $i.5]; set ch [string index $linetag 0]
-			if {$mt && ([string equal $linetag "@item"] || [string equal $linetag "@tab "])} {
+			if {$mt && ($linetag eq "@item" || $linetag eq "@tab ")} {
 				$t delete $i.0 $i.5
-				if {[string equal $linetag "@tab "]} {$t insert $i.0 "\t"}
+				if {$linetag eq "@tab "} {$t insert $i.0 "\t"}
 				$t insert $i.0 " "
 				set needindent 0
-			} elseif {[string equal $linetag "@item"]} {
+			} elseif {$linetag eq "@item"} {
 				set ex [string equal [$t get $i.5] "x"]
 				$t delete $i.0 $i.6+${ex}c; # @item+space
 				set itemlen 0; if {!$ex} {set itemlinelen 0}
-				if {[string equal $tag "itemize"]} {
-					if {[string equal [string trim [$t get $i.0 "$i.0 lineend"]] ""]} {
+				if {$tag eq "itemize"} {
+					if {[string trim [$t get $i.0 "$i.0 lineend"]] eq ""} {
 #puts "trim = [string trim [$t get $i.0 {$i.0 lineend}]]"
 						# not according to spec but fileutils' getdate.texi does it
 						$t delete $i.0 $i.0+1l; incr ie -1; #incr i -1; # preserves line end ("\n")
 					}
 					$t insert $i.0 $mark
-				} elseif {[string equal $tag "enumerate"]} {
+				} elseif {$tag eq "enumerate"} {
 					$t delete $i.0 $i.0+1l; incr ie -1
 					$t insert $i.0 [format $format $icnt]
 					incr icnt
@@ -380,19 +366,19 @@ proc texiMarkup {t start end {force 0}} {
 #puts "expr $itemlinelen+$itemlen for [$t get $i.0 $i.$itemlen]"
 					$t insert $i.0 "$type\{"
 					$t insert "$i.0 lineend" "\}\t"
-					if {$itemlinelen+$itemlen>12 && ![string equal [$t get "$i.0+1l" "$i.0+1l+5c"] "@item"]} {$t insert "$i.0+1l" " \t"}
+					if {$itemlinelen+$itemlen>12 && [$t get "$i.0+1l" "$i.0+1l+5c"] ne "@item"} {$t insert "$i.0+1l" " \t"}
 				}
 				if {$ex && [expr {$itemlinelen+$itemlen}]<50} {
-					if {[string equal $tag "table"]} {$t delete $i.0-2c}
+					if {$tag eq "table"} {$t delete $i.0-2c}
 					$t insert $i.0-1c ", "
 					$t delete $i.0-1c
 					incr i -1; incr ie -1
 					incr itemlinelen $itemlen
 				} else {$t insert $i.0 " "; set itemlinelen $itemlen}
 				set needindent 0
-			} elseif {[string equal $ch " "] || [string equal $ch "\t"]} {
+			} elseif {$ch eq " " || $ch eq "\t"} {
 				$t insert $i.1 "   "; # nested list/table (tried ... $i.0 " \t")
-			} elseif {[string equal $ch ""]} {
+			} elseif {$ch eq ""} {
 				set needindent 1
 			} elseif {$needindent} {
 #puts "inserting tab to: [$t get $i.0 [list $i.0 lineend]]"
@@ -401,7 +387,7 @@ proc texiMarkup {t start end {force 0}} {
 			}
 		}
 
-		if {![string equal [$t get $ie.0] "\n"]} {$t insert $ie.0 "\n"}
+		if {[$t get $ie.0] ne "\n"} {$t insert $ie.0 "\n"}
 		$t tag add $tabtag $s $ie.0
 #puts "[$t get $s $ie.0]\n\n"
 	}
@@ -421,10 +407,10 @@ proc texiMarkup {t start end {force 0}} {
 			pxref -
 			inforef {
 				foreach {nodename xrefname topic infofile printedmanual} [split $txt ","] break
-				if {[string equal $tag "inforef"]} {set tag "xref"}
-				set txt ""; if {[string equal $tag "xref"]} {set txt "See "} elseif {[string equal $tag "pxref"]} {set txt "see "}
+				if {$tag eq "inforef"} {set tag "xref"}
+				set txt ""; if {$tag eq "xref"} {set txt "See "} elseif {$tag eq "pxref"} {set txt "see "}
 				$t insert $s "$txt$nodename"; $t tag add texixref $s+[string length $txt]c "$s+[string length $txt]c+[string length $nodename]c"
-#				if {![string equal $xrefname ""]} {$t insert insert $xrefname}
+#				if {$xrefname ne ""} {$t insert insert $xrefname}
 			}
 
 			# tags with no effect
@@ -454,7 +440,7 @@ proc texiMarkup {t start end {force 0}} {
 			uref {
 				foreach {uref ureftxt} [split $txt ","] break
 				$t insert $s "<$uref>"; $t tag add tt $s "$s+[expr {2+[string length $uref]}]c"
-				if {![string equal $ureftxt ""]} {$t insert $s "$ureftxt "}
+				if {$ureftxt ne ""} {$t insert $s "$ureftxt "}
 			}
 			TeX {$t insert $s "TEX"; $t tag add subscript $s+1c}
 
@@ -479,7 +465,7 @@ proc texiMarkup {t start end {force 0}} {
 	# finally unquote metachars and zap single newlines to let Tk word wrap
 	# and accents with immediate letter (no {})
 	set rx {@[{}@:.?!*"'`~^\s]}
-	for {set s $start-1c} {![string equal [set s [$t search -regexp -elide $rx $s+1c $end]] ""]} {} {
+	for {set s $start-1c} {[set s [$t search -regexp -elide $rx $s+1c $end]] ne ""} {} {
 		set ch [$t get $s+1c]
 		switch -regexp $ch {
 			{\*} {
@@ -503,11 +489,11 @@ proc texiMarkup {t start end {force 0}} {
 	scan [$t index $start+1l] "%d" stop
 	# LATER condense multiple blank lines to one
 	# leave exactly one newline at end
-	for {scan [$t index $end-2l] "%d" i} {$i>$stop && [string equal [$t get $i.0] "\n"]} {incr i -1} {$t delete $i.0}
+	for {scan [$t index $end-2l] "%d" i} {$i>$stop && [$t get $i.0] eq "\n"} {incr i -1} {$t delete $i.0}
 	for {scan [$t index $end-1l] "%d" i} {$i>$stop} {incr i -1} {
 		if {[string first [$t get $i.0] " \n"]==-1 && [string first [$t get $i.0-1l] "\n"]==-1} {$t insert $i.0-1c " "; $t delete $i.0-1c}
 	}
-	for {scan [$t index $start] "%d" i} {[string equal [$t get $i.0] "\n"]} {incr i} {}
+	for {scan [$t index $start] "%d" i} {[$t get $i.0] eq "\n"} {incr i} {}
 	$t delete $start+1l $i.0
 
 	$t tag raise table
@@ -546,7 +532,7 @@ proc texiStruct {t type sectdelta name file byte} {
 #	$t insert end "$n  $name" $texilevelx($lev) "\n"; # -- numbered sections -> do at runtime if you want it but not in cache
 	# just number the toplevel?
 #	if {$lev==0} {
-#		set txt "$n  $name"; if {[string equal $type "appendix"]} {set txt [format "%c  %s" [expr $n+65] $name]}
+#		set txt "$n  $name"; if {$type eq "appendix"} {set txt [format "%c  %s" [expr $n+65] $name]}
 #		$t insert end $txt $texilevelx($lev) "\n"
 #	}
 
@@ -581,7 +567,7 @@ proc texiProcess {t file {curnode "Front Matter"}} {
 #		set realf $file
 #	} else {
 		set realf [lfirst [glob -nocomplain $file$manx(zoptglob)]]
-		if {[string equal $realf ""] || ![file readable $realf]} {return $sumbytes}
+		if {$realf eq "" || ![file readable $realf]} {return $sumbytes}
 #	}
 	set fid [open "|[manManPipe $realf]"]
 	fconfigure $fid -buffersize 102400; # helps a tiny bit
@@ -627,10 +613,10 @@ proc texiProcess {t file {curnode "Front Matter"}} {
 				set on 0; set endsed $texised($hit); continue
 			}
 		} else {
-			if {[string equal $endsed "end iftex"] && [regexp $struct $type]} {
+			if {$endsed eq "end iftex" && [regexp $struct $type]} {
 				# some Texinfo (e.g., emacs) hides structure within iftex -- skip the continue and process anyhow
 			} else {
-				if {[string equal $type $endsed] || [string equal $typename $endsed]} {set on 1}
+				if {$type eq $endsed || $typename eq $endsed} {set on 1}
 				continue
 			}
 		}
@@ -652,7 +638,7 @@ proc texiProcess {t file {curnode "Front Matter"}} {
 #puts "macro |$arg1|, |$arg2|, |$line|"
 			}
 			end {
-				if {[string equal $arg1 "ftable"]} {set inftable 0} elseif {[string equal $arg1 "vtable"]} {set invtable 0}
+				if {$arg1 eq "ftable"} {set inftable 0} elseif {$arg1 eq "vtable"} {set invtable 0}
 			}
 
 
@@ -677,7 +663,7 @@ proc texiProcess {t file {curnode "Front Matter"}} {
 				# "Write an `@syncodeindex' command ... at the beginning of a Texinfo file"
 				# merged-from always keeps its font
 				set mapfrom "${arg1}index"
-				foreach i [array names texiimap] {	if {[string equal $arg1 $texiimap($i)]} {set mapfrom $i; break}  }
+				foreach i [array names texiimap] {	if {$arg1 eq $texiimap($i)} {set mapfrom $i; break}  }
 				set texiimap($mapfrom) $arg2
 			}
 			defindex {lappend texiimap(${arg1}index) $arg1; lappend texiifont(${arg1}index) "asis"}
@@ -688,10 +674,10 @@ proc texiProcess {t file {curnode "Front Matter"}} {
 				set texienclose([string trim $cmd]) [list [string trim $before] [string trim $after]]
 			}
 			def* {
-				if {[string match "*x" $type]} {set type [string range $type 0 [expr [string length $type]-1-1]]}
+				if {[string match "*x" $type]} {set type [string range $type 0 [expr {[string length $type]-1-1}]]}
 				set spec $texidef($type)
 				foreach {index category} $spec break
-				set inx [expr [lsearch $spec "name"]-2+1]; if {[string equal $category "category"]} {incr inx}
+				set inx [expr {[lsearch $spec "name"]-2+1}]; if {$category eq "category"} {incr inx}
 				set name [lindex $all $inx]
 				lappend texiindex($texiimap($index)) [list $name $curnode $texiifont($index)]
 			}
@@ -708,9 +694,9 @@ proc texiProcess {t file {curnode "Front Matter"}} {
 
 			default {
 				# chapter, section, subsection, ...
-				set skipbyte [expr $byte0+$linelen]
-				if {[string equal $type "titlepage"]} {set type "chapter"; set name "Title Page"
-				} elseif {[string equal $type "centerchap"]} {set type "chapter"}
+				set skipbyte [expr {$byte0+$linelen}]
+				if {$type eq "titlepage"} {set type "chapter"; set name "Title Page"
+				} elseif {$type eq "centerchap"} {set type "chapter"}
 				#set name [string trimright $name "."]; # gdbm has periods after each section
 				if {[info exists texilevelx($type)] && $texilevelx($type)==0} {$t see end; update idletasks}
 
@@ -719,8 +705,8 @@ proc texiProcess {t file {curnode "Front Matter"}} {
 				while {[regsub -all "(^|\[^@])@value{(\[^\}]+)}" $name {\1$texiinfovar(\2)} name]} {}
 				set name [subst -nobackslashes -nocommands $name]
 
-				if {$lastbyte!=-1} {lappend texix($curmark) [expr $byte0-$lastbyte]}
-				if {[string equal $type "bye"]} break
+				if {$lastbyte!=-1} {lappend texix($curmark) [expr {$byte0-$lastbyte}]}
+				if {$type eq "bye"} break
 				set curmark [texiStruct $t $type $sectdelta $name $file $skipbyte]
 				set texix($curmark) [list $file $byte]; set texinode($curnode) $curmark
 				set lastbyte $skipbyte
@@ -728,7 +714,7 @@ proc texiProcess {t file {curnode "Front Matter"}} {
 		}
 	}
 	}
-	if {$lastbyte!=-1 && ![string equal $type "bye"]} {lappend texix($curmark) [expr {$byte0-$lastbyte}]}
+	if {$lastbyte!=-1 && $type ne "bye"} {lappend texix($curmark) [expr {$byte0-$lastbyte}]}
 
 	incr sumbytes $byte
 	return $sumbytes
@@ -747,7 +733,7 @@ proc texiCallback {t sect} {
 
 	# prefetch next section while reading current
 	# (maybe want to condition this on size)
-	if {![string equal $next "endcontent"] && ![string equal $next ""]} {after 100 texiFault $t $next}
+	if {$next ne "endcontent" && $next ne ""} {after 100 texiFault $t $next}
 #puts "read $sect, fault $next/$nextnext"
 }
 
@@ -756,14 +742,14 @@ proc texiFault {t sect} {
 	global texi manx texitrans curwin
 	foreach per {texix texiinfovar teximacro} {upvar #0 ${per}$t $per}; # maybe expand to $texi(persistent)
 
-	if {[string equal $texix($sect) ""]} return
+	if {$texix($sect) eq ""} return
 	set next [lindex $manx(nextposns$curwin) [lsearch $manx(sectposns$curwin) $sect]]
 
 	set txtstate [$t cget -state]; $t configure -state normal
 
 	foreach {f s len} $texix($sect) break
 	set point "$sect linestart+1l"
-	if {![string equal $texi(lastfile$t) $f]} {
+	if {$texi(lastfile$t) ne $f} {
 		cd $texi(cd$t)
 		set realf [lfirst [glob $f$manx(zoptglob)]]
 		set fid [open "|[manManPipe $realf]"]
@@ -877,7 +863,7 @@ proc texiShow {t f dir {force 0}} {
 	# caller should have done this checking
 	set realf [lfirst [glob -nocomplain $f$manx(zoptglob)]]
 	#if {![regexp {(.*\.tar[^/]*)} $file all realf]} {set realf [lfirst [glob -nocomplain $f$manx(zoptglob)]]}
-	if {[string equal $realf ""]} {$t insert end "doesn't exist!" b; return
+	if {$realf eq ""} {$t insert end "doesn't exist!" b; return
 	} elseif {![file readable $realf]} {$t insert end "not readable!" b; return
 	}
 
@@ -888,7 +874,7 @@ proc texiShow {t f dir {force 0}} {
 	# if in texinfodir, assume Tcl version already cached
 	# use CPU over disk
 	set cache [lfirst [glob -nocomplain [file join $dir "[file tail $f]$manx(zoptglob)"]]]
-	if {!$force && ![string equal $cache ""] && [file readable $cache] && [file mtime $cache]>[file mtime $realf] && [file mtime $cache]>$manx(mtime)} {
+	if {!$force && $cache ne "" && [file readable $cache] && [file mtime $cache]>[file mtime $realf] && [file mtime $cache]>$manx(mtime)} {
 # && ($manx(debug) ||)
 		set fid [open "|[manManPipe $cache]"]; set src [read $fid]; close $fid
 		eval $src
@@ -921,7 +907,7 @@ proc texiShow {t f dir {force 0}} {
 				set last ""
 				foreach tuple [lsort -dictionary -index 0 $texiindex($index)] {
 					set entry [lindex $tuple 0]
-					if {![string equal $entry $last]} {lappend content $tuple; set last $entry}
+					if {$entry ne $last} {lappend content $tuple; set last $entry}
 				}
 				set texiindex($index) $content
 			} else {
@@ -945,10 +931,11 @@ DEBUG {puts "\tno printindex for $index (length = [string length $texiindex($ind
 		catch {file delete -force $cache}
 		if {$time<1.5*1000000} {
 			# don't cache the small bills
-		} elseif {![file writable $dir] || (![string equal $cache ""] && [file exists $cache])} {
-			$t insert 1.0 "[file tail $f] not cached as $cache not writable\n" b "\n"
-			$t see 1.0
-			after 2000
+		} elseif {![file writable $dir] || ($cache ne "" && [file exists $cache])} {
+# interferes with outline making
+#			$t insert 1.0 "[file tail $f] not cached as $cache not writable\n" b "\n"
+#			$t see 1.0
+#			after 2000
 		} else {
 			# write out state: outline text+tags, node xref, numbered marks, index, 
 			# creates long lines, but result not meant for human manipulation
@@ -1029,7 +1016,7 @@ proc texiDatabase {dir} {
 		while {![eof $fid]} {
 			gets $fid line
 			if {[regexp $topregexp $line all name f suffix Zignore desc]} {
-				if {[string equal $suffix "info"]} {lappend form $f b "-- .info files are formatted text; you want .texi/.texinfo Texinfo " "" "source" i "\n" {}; continue}
+				if {$suffix eq "info"} {lappend form $f b "-- .info files are formatted text; you want .texi/.texinfo Texinfo " "" "source" i "\n" {}; continue}
 				set realf [lfirst [glob -nocomplain [zapZ $f]$manx(zoptglob)]]
 				#if {[regexp {(.*\.tar[^/]*)} $f all tar]} {set zapf $tar} else {set zapf $f}
 				#set realf [lfirst [glob -nocomplain [zapZ $zapf]$manx(zoptglob)]]
@@ -1076,19 +1063,19 @@ proc texiSearch {w} {
 	global man manx texiback texi
 	set MAXSECT 10
 
-	if {[string equal $man(gzgrep) ""]} return
+	if {$man(gzgrep) eq ""} return
 	set t $w.show
 	upvar #0 texiback$t texiback texix$t texix
 
 	set pat $manx(search,string$w)
-	if {[string equal [string trim $pat] ""]} return
+	if {[string trim $pat] eq ""} return
 #	if {$texi(sectcnt)==0} {
 #		# all sections loaded; don't have to search on disk
 #	=>	# how to make visible all sections headers with hits?  regular search should do this
 #		return 
 #
 #	} else
-	if {![string equal $pat $texi(lastsearch$t)]} {
+	if {$pat ne $texi(lastsearch$t)} {
 		# Showing hits in text already faulted in.  to search all text (on disk) search again with same pattern.  unfortunately, first quick search is slow as fault in indexes
 		foreach sect $texi(printindex) { texiFault $t $sect }
 		after 1000 "manWinstdout $w {Index and header search done; search again for full search.}"
@@ -1116,12 +1103,12 @@ proc texiSearch {w} {
 		set lasthit ""
 		foreach hit [split $hits "\n"] {
 			regexp {(([^:]+):)?(\d+)} $hit all junk file b; zapZ! file
-			if {[string equal $file ""]} {set file [lfirst $texiback(filez)]}; # only one file so grep doesn't report filename
+			if {$file eq ""} {set file [lfirst $texiback(filez)]}; # only one file so grep doesn't report filename
 			set lastsect ""
 			foreach pair $texiback($file) {
 				foreach {sect s} $pair break
 				if {$s>$b} {
-					if {![string equal $lastsect ""] && ![string equal $lastsect $lasthit]} {lappend secthits $lastsect}
+					if {$lastsect ne "" && $lastsect ne $lasthit} {lappend secthits $lastsect}
 					set lasthit $lastsect
 					break
 				}
@@ -1133,7 +1120,7 @@ proc texiSearch {w} {
 	}
 	set texi(lastsearch$t) $pat; set texi(lasthits$t) $secthits
 
-	set newsecthits {}; foreach sect $secthits {if {![string equal $texix($sect) ""]} {lappend newsecthits $sect}}
+	set newsecthits {}; foreach sect $secthits {if {$texix($sect) ne ""} {lappend newsecthits $sect}}
 
 	# always show hit's enclosing section
 	after 100 "foreach sect [list $secthits] {$t tag add $man(search-show) \"\$sect linestart\" \"\$sect lineend\"}"
@@ -1160,16 +1147,16 @@ proc texiXref {t} {
 #puts "\a$ref"
 		# get index group
 		set inxes [array names texiindex]
-		for {set mark current} {![string equal $mark ""]} {set mark [$t mark previous $mark]} {
+		for {set mark current} {$mark ne ""} {set mark [$t mark previous $mark]} {
 			if {[lsearch -exact $inxes $mark]!=-1} break
 		}
-		if {[string equal $mark ""]} return; # fail
+		if {$mark eq ""} return; # fail
 #puts "mark = $mark"
 
 		# now count forward until get to entry
 		set centry [lfirst [$t tag prevrange texixref current+1c]]; set cmark [$t index $mark]
 		foreach {now next} [$t tag nextrange texixref $cmark] break
-		for {set off 0} {![string equal $now $centry]} {incr off} {
+		for {set off 0} {$now ne $centry} {incr off} {
 			foreach {now next} [$t tag nextrange texixref $next+1c] break
 		}
 #puts "off = $off"
@@ -1179,9 +1166,9 @@ proc texiXref {t} {
 	}
 
 
-#	if {[string equal $sect ""]} { fuzzy(?) search on headings }
+#	if {$sect eq ""} { fuzzy(?) search on headings }
 
-	if {![string equal $sect ""]} {
+	if {$sect ne ""} {
 #puts "hit: $sect"
 		searchboxKeyNav C space 0 $t; # so C-x goes back to start
 		manOutline $t 0 $sect
