@@ -3,7 +3,7 @@
 #
 #   initial prototype written March 24-25, 1993
 #
-#   Copyright (c) 1994-1999  Thomas A. Phelps
+#   Copyright (c) 1994-2003  Thomas A. Phelps
 #
 
 
@@ -32,11 +32,11 @@ proc manShortcuts {w cmd} {
 #puts "$manx(man$w) => $manx(name$w).$manx(cursect$w)"
 
 	set modeok [lmatch {man txt texi} $manx(mode$w)]
-	if {![string equal $cmd "init"] && (!$modeok || [string equal $manx(man$w) ""])} return
+	if {$cmd ne "init" && (!$modeok || $manx(man$w) eq "")} return
 
 	set present [expr {[lsearch -exact $manx(shortcuts) $me]!=-1}]
-	if {[string equal $cmd "add"] && !$present} {lappend manx(shortcuts) $me; set short($me) [clock seconds]
-	} elseif {[string equal $cmd "sub"] && $present} {set manx(shortcuts) [lfilter $me $manx(shortcuts)]}
+	if {$cmd eq "add" && !$present} {lappend manx(shortcuts) $me; set short($me) [clock seconds]
+	} elseif {$cmd eq "sub" && $present} {set manx(shortcuts) [lfilter $me $manx(shortcuts)]}
 
 	# update menu
 	set m .shortcuts
@@ -97,7 +97,7 @@ proc manHotSpot {cmd t xy} {
 #	}
 
 	# act on command
-	if {[string equal $cmd "clear"]} {
+	if {$cmd eq "clear"} {
 		$t tag remove hot 1.0 end
 		return
 	}
@@ -112,7 +112,7 @@ proc manHotSpot {cmd t xy} {
 
 	# command line options trump
 # FLAT, RAISED, SUNKEN, GROOVE, SOLID, or RIDGE
-	if {0 && [string equal $manx(mode$curwin) "man"] && ([$t get [set cmdstart "$xy wordstart-1c"]]=="-" || [$t get [set cmdstart "$xy wordstart"]]=="-")} {
+	if {0 && $manx(mode$curwin) eq "man" && ([$t get [set cmdstart "$xy wordstart-1c"]] eq "-" || [$t get [set cmdstart "$xy wordstart"]] eq "-")} {
 		set skipe "\[]\[\t .,;:\{\}?\]"
 		scan [$t index $cmdstart] "%d.%d" line char
 		for {set c0 $char} {$c0>0 && ![regexp $skipe [$t get $line.$c0]]} {incr c0 -1} {}
@@ -132,9 +132,9 @@ proc manHotSpot {cmd t xy} {
 ### 8.0: possible to take advantage of tcl_endOfWord?
 	# special cases when clicking on parentheses
 	set c [$t get $line.$char]
-	if {[string equal $c "("]} {
+	if {$c eq "("} {
 		if {$char>0 && [$t get $line.$char-1c]!=" "} {incr char -1} else {incr char}
-	} elseif {[string equal $c ")"]} {
+	} elseif {$c eq ")"} {
 		if {$char>0} {incr char -1}
 	}
 
@@ -145,26 +145,26 @@ proc manHotSpot {cmd t xy} {
 
 	# gobble characters forwards
 	for {set cn $char} {$cn<=$lineend && [regexp -nocase $manchars [set c [$t get $line.$cn]]]} {incr cn} {
-		if {[string equal $c "("]} {
+		if {$c eq "("} {
 			if {!$lparen} {set lparen $cn} else break
-		} elseif {[string equal $c ")"]} {
+		} elseif {$c eq ")"} {
 			if {!$rparen} {set rparen $cn; incr cn}
 			break
-		} elseif {[string equal $c ":"] && ([string is space [$t get $line.$cn+1c]] || [string is space [$t get $line.$cn-1c]])} {
+		} elseif {$c eq ":" && ([string is space [$t get $line.$cn+1c]] || [string is space [$t get $line.$cn-1c]])} {
 			break
 		} elseif {[string is space $c]} {
-			if {!$lparen && !$fspace && $cn<$lineend && [string equal [$t get $line.$cn+1c] "("]} {set fspace 1} else break
+			if {!$lparen && !$fspace && $cn<$lineend && [$t get $line.$cn+1c] eq "("} {set fspace 1} else break
 		}
 	}
 	incr cn -1
 
 	# gobble characters backwards
 	for {set c0 $char} {$c0>=0 && [regexp -nocase $manchars [set c [$t get $line.$c0]]]} {incr c0 -1} {
-		if {[string equal $c "("]} {
+		if {$c eq "("} {
 			if {!$lparen} {set lparen $c0} else break
-		} elseif {[string equal $c ")"]} {
+		} elseif {$c eq ")"} {
 			break
-		} elseif {[string equal $c ":"] && ([string is space [$t get $line.$c0+1c]] || [string is space [$t get $line.$c0-1c]])} {
+		} elseif {$c eq ":" && ([string is space [$t get $line.$c0+1c]] || [string is space [$t get $line.$c0-1c]])} {
 			break
 		} elseif {[string is space $c]} {
 			if {$lparen==[expr {$c0+1}] && !$fspace} {set fspace 1} else break
@@ -192,7 +192,7 @@ proc manHotSpot {cmd t xy} {
 		set cn [expr {$lparen-1}]
 
 	# if have good parens, can't start with a "/"
-	} elseif {$lparen && $rparen && [string equal [$t get $line.$c0] "/"]} {
+	} elseif {$lparen && $rparen && [$t get $line.$c0] eq "/"} {
 		incr c0
 	} 
 
@@ -233,7 +233,7 @@ proc manOutput {} {
 	foreach i [lsort -dictionary $wins] {
 		set title "#[string range $i 4 end]"
 		# special case for main window
-		if {[string equal $title "#"]} {append title 1}
+		if {$title eq "#"} {append title 1}
 		lappend titleList $title $i
 	}
 
@@ -339,7 +339,7 @@ proc manNewMode {w mode {n {""}}} {
 		set y $csy
 	}
 	# set to first nonblank line
-	while {[$t compare $y < end] && [string equal [$t get $y] "\n"]} {append y "+1l"}
+	while {[$t compare $y < end] && [$t get $y] eq "\n"} {append y "+1l"}
 #puts "save y for $manx(hv$w)"
 	set manx(yview,$manx(hv$w)) [manPosn2OutnOff $t $y]
 
@@ -359,7 +359,7 @@ proc manNewMode {w mode {n {""}}} {
 	set manx(search,oldstring$w) ""
 	manLineCnt $w ""
 	searchboxKeyNav "" Escape 0 $t $w.info 0
-#	if {[string equal $mode "section"]} {searchboxKeyNav C s 0 $t "" 1}
+#	if {$mode eq "section"} {searchboxKeyNav C s 0 $t "" 1}
 	after 5 selection clear $t
 
 #	set sbx(lastkeys$w) ""
@@ -404,7 +404,7 @@ proc manPosn2OutnOff {t posn} {
 
 	if {[catch {scan [$t index $posn] "%d.%d" line char}]} return
 	for {set s $posn+2c} {$s!="" && ![string match "js*" $s]} {set s [$t mark previous $s]} {}
-	if {[string equal $s ""]} {return "1/0.0"}
+	if {$s eq ""} {return "1/0.0"}
 
 	scan [$t index $s] "%d" basestartline
 	regexp {js(.*)} $s all basenum
@@ -427,7 +427,7 @@ proc manHyper {w {n ""}} {
 		}
 	}
 
-	if {[string equal $man(hyperclick) "double"]} {set mod "Double-"} else {set mod ""}
+	if {$man(hyperclick) eq "double"} {set mod "Double-"} else {set mod ""}
 	$t tag bind hyper <ButtonRelease-1> "
 		if {\$manx(hotman$t)!={}} { set manx(typein$w) \$manx(hotman$t) }
 	"
@@ -479,7 +479,7 @@ proc manTextClose {w} {
 	set t $w.show
 
 	# zap final newline so last line is flush with bottom
-	if {[string equal [$t get "end -2c"] "\n"]} {$t delete "end -2c"}
+	if {[$t get "end -2c"] eq "\n"} {$t delete "end -2c"}
 
 	$t tag add hyper 1.0 end
 
@@ -499,7 +499,7 @@ proc manResetEnv {} {
 
 	# also updates contents of volume listings
 	foreach i $manx(manList) {
-		if {[lsearch $manx(specialvols) $i]==-1 || [string equal $i "all"]} {set mani($i,form) ""}
+		if {[lsearch $manx(specialvols) $i]==-1 || $i eq "all"} {set mani($i,form) ""}
 	}
 }
 
@@ -540,7 +540,7 @@ proc manMenuFit {m} {
 	global man manx
 
 	if {[winfo class $m]!="Menu"} {puts stderr "$m not of Menu class"; exit 1}
-	if {[string equal [$m index last] "none"]} return
+	if {[$m index last] eq "none"} return
 
 	set sh [winfo screenheight $m]
 
@@ -600,6 +600,7 @@ proc manShowManFoundSetText {w t key} {
 
 
 	set alljs [lmatches "js*" [$t mark names]]
+	if {[llength $alljs]==0} {set alljs 1.0}
 	set manx(sectposns$w) [lsort -dictionary $alljs]
 	set manx(nextposns$w) [concat [lrange $manx(sectposns$w) 1 end] endcontent]
 	set manx(cursect$t) [lfirst $manx(sectposns$w)]
@@ -610,7 +611,7 @@ proc manShowManFoundSetText {w t key} {
 	# count lines in each section (not shown for short sections)
 	set manx(sectname$t) {}
 	# can speed up processing of Texinfo by processing in bulk, which is good because they have many header lines
-	if {[string equal $manx(mode$w) "texi"]} {
+	if {$manx(mode$w) eq "texi"} {
 		if {$man(showsectmenu)} {set manx(sectname$t) [split [$t get [lfirst $manx(sectposns$w)] "[llast $manx(sectposns$w)] lineend"] "\n"]} else {set manx(sectname$t) ""}
 		foreach now $manx(sectposns$w) {set manx(lcnt$now) [set manx(lcnt0$now) 0]}
 		$t tag remove hyper 1.0 end
@@ -619,7 +620,7 @@ proc manShowManFoundSetText {w t key} {
 		foreach now $manx(sectposns$w) next $manx(nextposns$w) {
 			lappend manx(sectname$t) [$t get $now "$now lineend"]
 			scan [$t index $next] "%d" linenext
-			set manx(lcnt$now) [set manx(lcnt0$now) [expr $linenext-$linenow-1]]
+			set manx(lcnt$now) [set manx(lcnt0$now) [expr {$linenext-$linenow-1}]]
 			set linenow $linenext
 		}
 		$t tag remove hyper $now "$now lineend"
@@ -631,19 +632,19 @@ proc manShowManFoundSetText {w t key} {
 		lappend manx(sectlevels$t) [regsub -all {\.} $now {\.} junk]
 
 		for {set sup $now} {[regexp $manx(supregexp) $sup all supnum]} {set sup "js$supnum"} {
-			catch {incr manx(lcntjs$supnum) [expr $manx(lcnt$now)+1]}
+			catch {incr manx(lcntjs$supnum) [expr {$manx(lcnt$now)+1}]}
 		}
 
 		set skip($now) 0
 
 		# crunch short man sections, unless man(outline) off 
-		if {[string equal $manx(mode$w) "man"] && ![string equal $man(outline) "off"] && ($manx(lcnt$now)<=2 || ($manx(lcnt$now)<=5 && ![string equal $secttxt "Synopsis"] && ![string equal $secttxt "Files"])) && [lsearch -glob $manx(sectposns$w) $now.*]==-1} {
+		if {$manx(mode$w) eq "man" && $man(outline) ne "off" && ($manx(lcnt$now)<=2 || ($manx(lcnt$now)<=5 && $secttxt ne "Synopsis" && $secttxt ne "Files")) && [lsearch -glob $manx(sectposns$w) $now.*]==-1} {
 			set ss "$now linestart+1l"; set se "$now linestart+1l+$manx(lcnt$now)l"
 			set fNAME [string equal $secttxt "Name"]; # normalized by RosettaMan
 #			set fSYNOPSIS [string equal $secttxt "Synopsis"]; # only used once, not in loop
 
 			# quick feasiblity check
-			if {[$t compare "$ss+[expr $manx(screencols)*2]c" > $se]} {
+			if {[$t compare "$ss+[expr {$manx(screencols)*2}]c" > $se]} {
 			set utxt [$t get $ss $se]; regsub -all " +" $utxt "" txt; set txtlen [string length $txt]
 #			if {$txtlen<60 || ($txtlen<80 && $fNAME)} {
 #			if {$txtlen<$man(columns)-10 || ($txtlen<$man(columns)*1.1 && $fNAME)} {
@@ -680,9 +681,9 @@ proc manShowManFoundSetText {w t key} {
 
 
 
-	set manx(tryoutline$w) [expr {[string equal $manx(mode$w) "texi"] || (![string equal $man(outline) "off"]
+	set manx(tryoutline$w) [expr {$manx(mode$w) eq "texi" || ($man(outline) ne "off"
 						  # exceptions: help page, full page fits on screen
-						  && ![string equal $manx(manfull$w) "_help"] && [string equal [$t bbox endcontent] ""])}]
+						  && $manx(manfull$w) ne "_help" && [$t bbox endcontent] eq "")}]
 
 
 	### after reading in text, build sections menu, count lines, show highlights
@@ -702,7 +703,7 @@ proc manShowManFoundSetText {w t key} {
 			# expand/collapse section and subsections by clicking on title
 			if {!$skip($now)} {
 				set closed 1; set imagename "closed"
-				if {[string equal $manx(mode$w) "man"] && ([string equal $man(outline) "allexp"] || ([string match "allbut*" $man(outline)] && [regexp -nocase $man(outlinebut) $secttxt$manx(lcnt$now)]))} {set closed ""; set imagename "opened"}
+				if {$manx(mode$w) eq "man" && ($man(outline) eq "allexp" || ([string match "allbut*" $man(outline)] && [regexp -nocase $man(outlinebut) $secttxt$manx(lcnt$now)]))} {set closed ""; set imagename "opened"}
 
 				set tags [$t tag names "$now linestart"]
 				$t image create "$now linestart" -image $imagename
@@ -715,11 +716,11 @@ proc manShowManFoundSetText {w t key} {
 				$t tag configure area$now -elide $closed
 				$t tag add outline "$now linestart" "$now lineend"; # if +1l can click to area off the right
 				# maybe indent heading only, not body
-				set lmar [expr 0.3*(1+$level)]c; $t tag configure area$now -lmargin1 $lmar -lmargin2 $lmar
+				set lmar [expr {0.3*(1+$level)}]c; $t tag configure area$now -lmargin1 $lmar -lmargin2 $lmar
 			}
 
 			# man page subsections always visible
-			if {$level>0 && [string equal $manx(mode$w) "man"]} {$t tag add alwaysvis "$now linestart" "$now lineend+1c"}
+			if {$level>0 && $manx(mode$w) eq "man"} {$t tag add alwaysvis "$now linestart" "$now lineend+1c"}
 
 			# at start of new entity at that level, close up everything at that level and below (== higher #)
 			for {set j $level} {$j<$manx(MAXLEVELS)} {incr j} {
@@ -762,16 +763,16 @@ proc manMakeSectMenuAfter {w t} {
 		$m add command -label "Toggle current" -accelerator "Button 1 on header" -command "manOutline $t -1 \$manx(cursect$t)"
 		$m add command -label "Current + hierarchy" -accelerator "Shift-Button 1 on header" -command "manOutline $t -1 \$manx(cursect$t) 1"
 # believe me, you don't want this
-#		if {[string equal $manx(mode$w) "man"]} {$m add command -label "Expand All" -command "manOutline $t {} * 1; $t yview moveto 0"}
+#		if {$manx(mode$w) eq "man"} {$m add command -label "Expand All" -command "manOutline $t {} * 1; $t yview moveto 0"}
 		# warning: on=0
 
 		set manx(texishowsubs) ""
-		if {[string equal $manx(mode$w) "texi"]} {
+		if {$manx(mode$w) eq "texi"} {
 			$m add checkbutton -label "Show All Subsection Heads" -variable manx(texishowsubs) -onvalue 0 -offvalue "" -command "foreach tag {section subsection subsubsection} {$t tag configure \$tag -elide \$manx(texishowsubs); $t tag raise \$tag}; $t yview moveto 0"
 			if {[catch {$t index js2}] || [llength $manx(sectposns$w)]<40} {$w.sections.m invoke "last"}
 		}
 		$m add command -label "Collapse current" -accelerator "Button 3 anywhere" -command "manOutline $t 1 \$manx(cursect$t)"
-		$m add command -label "Collapse all" -accelerator "Double-Button 3" -command "manOutline $t 1 *; $t yview moveto 0; if {\[string equal \$manx(mode$w) \"man\"\]} {notemarks $w $t}"
+		$m add command -label "Collapse all" -accelerator "Double-Button 3" -command "manOutline $t 1 *; $t yview moveto 0; if {\$manx(mode$w) eq \"man\"} {notemarks $w $t}"
 		$m add separator
 	}
 
@@ -803,7 +804,7 @@ proc manMakeSectMenuAfter {w t} {
 	}
 
 #	if {![string match "_*" $key] && $man(headfoot)!=""} {
-	if {[string equal $manx(mode$w) "man"] && ![string equal $man(headfoot) ""]} {
+	if {$manx(mode$w) eq "man" && $man(headfoot) ne ""} {
 		$m add separator
 		$m add command -label "Header and Footer" -command "incr stat(page-section); $t yview endcontent"
 #headfoot"
@@ -821,7 +822,7 @@ proc manYview {w} {
 	global manx man
 
 	set t $w.show
-	if [catch {set y $manx(yview,$manx(hv$w))}] {set y "1/1.0"
+	if {[catch {set y $manx(yview,$manx(hv$w))}]} {set y "1/1.0"
 	} else {
 		# with outlining, hard to determine last scroll position, so just highlight it
 #$t tag remove lastposn 1.0 end; 
@@ -829,7 +830,7 @@ proc manYview {w} {
 		regexp {(.*)/(.*)\.(.*)} $y all sect loff coff; set y "js$sect+${loff}l+${coff}c"
 #puts $y
 		if {[$t index $y]!=1.0} {
-			if $manx(tryoutline$w) {nb $t lastposn $y $y} else {manOutlineYview $t $y}
+			if {$manx(tryoutline$w)} {nb $t lastposn $y $y} else {manOutlineYview $t $y}
 		}
 #		unset manx(yview,$manx(hv$w))
 	}
@@ -849,7 +850,7 @@ proc manOutlineYview {t line} {
 proc manOutlineSect {t sect} {
 	global manx curwin
 
-	if [catch {set now [$t index $sect]}] {return 0.0}
+	if {[catch {set now [$t index $sect]}]} {return 0.0}
 	regexp {(.*)/(.*)} [manPosn2OutnOff $t $sect] all new junk
 #	set new [lfirst $manx(sectposns$curwin)]
 #	foreach try $manx(sectposns$curwin) {
@@ -870,17 +871,17 @@ proc manDownSmart {w t} {
 	incr stat(page-downsmart)
 
 	set sect $manx(cursect$t)
-	if {[string equal [$t bbox $sect] ""]} {
+	if {[$t bbox $sect] eq ""} {
 		set sect [manOutlineSect $t @0,0]
-		if {[string equal [$t bbox $sect] ""]} {
-			set sect [lindex $manx(sectposns$w) [expr 1+[lsearch $manx(sectposns$w) $sect]]]
+		if {[$t bbox $sect] eq ""} {
+			set sect [lindex $manx(sectposns$w) [expr {1+[lsearch $manx(sectposns$w) $sect]}]]
 		}
 	}
 
 	set x [lsearch $manx(sectposns$w) $sect]
 	while 1 {
 		set openme [lindex $manx(sectposns$w) $x]
-		if {[string equal $openme ""] || [string equal [$t bbox $openme] ""]} {
+		if {$openme eq "" || [$t bbox $openme] eq ""} {
 			$t yview scroll 1 pages
 			break
 
@@ -888,9 +889,9 @@ proc manDownSmart {w t} {
 			# optionally collapse previous at same level: 
 			# high level structural context more important than last few lines of previous section
 
-			if $man(tidyout) {
+			if {$man(tidyout)} {
 				set level [regsub -all {\.} $openme {\.} junk]; set curlevel 1000
-				for {set i [expr $x-1]} {$i>=0} {incr i -1} {
+				for {set i [expr {$x-1}]} {$i>=0} {incr i -1} {
 					set cursect [lindex $manx(sectposns$w) $i]
 					set curlevel [regsub -all {\.} $cursect {\.} junk]
 					if {$curlevel<$level} {$t see $cursect; break}
@@ -916,20 +917,20 @@ proc manOutline {t finv sect {prop 0}} {
 
 	set time0 [clock clicks]
 
-	if {!$manx(tryoutline$curwin) || [string equal [string trim $sect] ""]} return
+	if {!$manx(tryoutline$curwin) || [string trim $sect] eq ""} return
 
 	# if explicitly playing with one section, don't subsequently open all of them
 	set manx(hitlist$t) {}
 
 
-	if {[string equal $sect "*"]} {set sect $manx(sectposns$curwin)}
+	if {$sect eq "*"} {set sect $manx(sectposns$curwin)}
 
 	if {[llength $sect]>1} {
 		foreach s $sect {manOutline $t $finv $s $prop}
 		return
-	} elseif ![string match "js*" $sect] {
+	} elseif {![string match "js*" $sect]} {
 		# if not passed an outline tag, search for nearest previous one
-		if [catch {set now [$t index $sect]}] return
+		if {[catch {set now [$t index $sect]}]} return
 		set sect [manOutlineSect $t $sect]
 	}
 
@@ -942,7 +943,7 @@ proc manOutline {t finv sect {prop 0}} {
 	if {$finv==""} { foreach tag $manx(show-ftags) {$t tag remove $tag 1.0 end} }
 
 	set sects $sect
-	if $prop {
+	if {$prop} {
 		set su $sect
 		# close up parents
 		if {$finv=="1"} {
@@ -951,7 +952,7 @@ proc manOutline {t finv sect {prop 0}} {
 		# open up all children
 		} else {
 			set lev [regsub -all {\.} $sect {\.} junk]
-			foreach s [lrange $manx(sectposns$curwin) [expr 1+[lsearch $manx(sectposns$curwin) $sect]] end] {
+			foreach s [lrange $manx(sectposns$curwin) [expr {1+[lsearch $manx(sectposns$curwin) $sect]}] end] {
 				if {[regsub -all {\.} $s {\.} junk] <= $lev} break
 				lappend sects $s
 			}
@@ -962,7 +963,7 @@ proc manOutline {t finv sect {prop 0}} {
 	# maintain context
 	if {$finv!=1} {
 		$t yview [set manx(cursect$t) $sect]
-		if {[string equal [$t dlineinfo $sect-5l] ""]} {$t yview scroll -5 units}
+		if {[$t dlineinfo $sect-5l] eq ""} {$t yview scroll -5 units}
 	}
 
 # this is very fast now -- if $manx(mondostats) {manWinstdout $curwin "[lfirst [manWinstdout $curwin]]    time [expr ([clock clicks]-$time0)/1000000.0] sec"}
@@ -975,7 +976,7 @@ proc manOutline2 {t finv sect} {
 
 	# if showing, show parent too
 	if {$finv!=1} {
-		if [regexp $manx(supregexp) $sect all num] {manOutline2 $t $finv "js$num"}
+		if {[regexp $manx(supregexp) $sect all num]} {manOutline2 $t $finv "js$num"}
 	}
 	if {[lsearch $manx(sectposns$curwin) $sect]==-1 || [lsearch -exact [$t tag names $sect] outline]==-1} return
 
@@ -993,7 +994,7 @@ proc manOutline2 {t finv sect} {
 
 	# generalize this
 	# if Texinfo, may need to format (after expansion, otherwise have to search in nested elide)
-	if {$finv!=1 && [string equal $manx(mode$curwin) "texi"]} {
+	if {$finv!=1 && $manx(mode$curwin) eq "texi"} {
 # && $texix($sect)!=""} {
 		cursorBusy 0
 		texiCallback $t $sect; # use anchored points to ease bookkeeping for texiMarkup
@@ -1010,9 +1011,9 @@ proc manLineCnt {w cnt {unit ""}} {
 	if {$cnt==""} {$w.search.cnt configure -text ""; return}
 
 	if {$unit==""} {
-		if {[string equal $man(lengthchunk) ""]} return;	# no report
+		if {$man(lengthchunk) eq ""} return;	# no report
 		set unit [textmanip::plural $cnt $man(lengthchunk)]
-		set cnt [expr 1+int($cnt/$manx($man(lengthchunk)-scale))]
+		set cnt [expr {1+int($cnt/$manx($man(lengthchunk)-scale))}]
 	}
 	$w.search.cnt configure -text "$cnt $unit"
 }
@@ -1051,13 +1052,13 @@ proc manShowManStatus {w} {
 
 	# history - save entire path, including any compression suffix
 	set manx(history$w) \
-		[lrange [setinsert $manx(history$w) 0 [list $manx(manfull$w)]] 0 [expr $man(maxhistory)-1]]
+		[lrange [setinsert $manx(history$w) 0 [list $manx(manfull$w)]] 0 [expr {$man(maxhistory)-1}]]
 	# should do this as a postcommand, but that's too messy
 	set m [set mb $w.history].m
 	$m delete 0 last
 	$m post 0 0; $m unpost; # needed to compensate for Tk menu bug
 	foreach i $manx(history$w) {
-		if {[llength [lfirst $i]]>=2} {set l [lfirst $i]} {set l $i}
+		if {[llength [lfirst $i]]>=2} {set l [lfirst $i]} else {set l $i}
 		if {![regexp {^[|<]} $l]} {set l [zapZ [file tail $l]]}
 		$m add command -label $l -command "incr stat(man-history); manShowMan $i {} $w"
 	}
@@ -1076,13 +1077,13 @@ proc manShowManStatus {w} {
 
 	# page count statistics
 	set f [zapZ $manx(manfull$w)]
-	if ![string match "<*" $f] {set f [file tail $f]}
-	if ![info exists pagecnt($f)] {set pagecnt($f) [list 0 0 -1 0 [clock seconds]]}
+	if {![string match "<*" $f]} {set f [file tail $f]}
+	if {![info exists pagecnt($f)]} {set pagecnt($f) [list 0 0 -1 0 [clock seconds]]}
 
 	foreach {times lasttime cksum nlines firsttime} $pagecnt($f) break
 	if {$firsttime==""} {set firsttime [clock seconds]}
 	if {$cksum==""} {set cksum -1}
-	set pagecnt($f) [list [expr 1+$times] [clock seconds] $cksum $linecnt $firsttime]
+	set pagecnt($f) [list [expr {1+$times}] [clock seconds] $cksum $linecnt $firsttime]
 }
 
 
@@ -1117,6 +1118,7 @@ proc manShowText {f0 {w .man} {keep 0}} {
 
 	if {[string match <* $f0]} {
 		set f [fileexp [string range $f0 1 end]]
+		if {[string length $f]==0} return
 		if {[regexp $manx(zregexp) $f]} {set f "|$man(zcat) $f"}
 # {set f "|cat $f"}
 	} else {set f [pipeexp $f0]}
@@ -1135,7 +1137,7 @@ proc manShowText {f0 {w .man} {keep 0}} {
 	manTextClose $w
 	if {!$keep} {pack forget $w.dups}
 
-	if [file isfile $f] {cd [file dirname [glob $f]]}
+	if {[file isfile $f]} {cd [file dirname [glob $f]]}
 
 
 	### update status information
@@ -1246,18 +1248,18 @@ proc manShowRfc {f0 {w .man} {keep 0}} {
 	set t $w.show
 	set state [$t cget -state]
 	$t configure -state normal
-	while {[string equal [$t get 1.0] "\n"]} {$t delete 1.0}
+	while {[$t get 1.0] eq "\n"} {$t delete 1.0}
 	set index 1.0
 	while {[set index [$t search -forwards -regexp "^\f" $index end]]!=""} {
 #puts "back @ $index"
 		scan [$t index "$index linestart -1l"] "%d" back
-		while {![string equal [$t get $back.0] "\n"]} {incr back -1}
-		while {[string equal [$t get $back.0] "\n"]} {incr back -1}
+		while {[$t get $back.0] ne "\n"} {incr back -1}
+		while {[$t get $back.0] eq "\n"} {incr back -1}
 		incr back
 #puts "forward @ $index"
 		scan [$t index "$index linestart +1l"] "%d" forward
-		while {[$t compare $forward.0 < end] && ![string equal [$t get $forward.0] "\n"]} {incr forward}
-		while {[$t compare $forward.0 < end] && [string equal [$t get $forward.0] "\n"]} {incr forward}
+		while {[$t compare $forward.0 < end] && [$t get $forward.0] ne "\n"} {incr forward}
+		while {[$t compare $forward.0 < end] && [$t get $forward.0] eq "\n"} {incr forward}
 		incr forward -1
 		$t delete $back.0 "$forward.0 lineend"; # keep a \n separation (sometimes right, sometimes wrong)
 	}
@@ -1291,11 +1293,11 @@ proc manShowRfc {f0 {w .man} {keep 0}} {
 proc manApropos {name {w .man}} {
 	global man manx mani stat
 
-	if $manx(shift) { set manx(shift) 0; set w [manInstantiate] }
+	if {$manx(shift)} { set manx(shift) 0; set w [manInstantiate] }
 	set wi $w.info; set t $w.show
 
-	if {[string equal $name ""]} {set name $manx(man$w)}
-	if {[string equal $name ""]} {
+	if {$name eq ""} {set name $manx(man$w)}
+	if {$name eq ""} {
 		manWinstderr $w "Type in keywords to search for"
 		return
 	}
@@ -1305,8 +1307,8 @@ proc manApropos {name {w .man}} {
 	manWinstdout $w "Apropos search for \"$name\" ..." 1
 
 DEBUG {puts "manApropos: exec $man(apropos) $name $man(aproposfilter) 2>/dev/null"}
-	if {[catch {set tmp [eval exec "$man(apropos) $name $man(aproposfilter) 2>/dev/null"]} info] || [string equal [string trim $tmp] ""]} {
-		if {![string equal $info ""]} {
+	if {[catch {set tmp [eval exec "$man(apropos) $name $man(aproposfilter) 2>/dev/null"]} info] || [string trim $tmp] eq ""} {
+		if {$info ne ""} {
 			lappend form $info i
 		} else {
 			lappend form "Nothing related found.\n" i
@@ -1327,7 +1329,7 @@ DEBUG {puts "manApropos: exec $man(apropos) $name $man(aproposfilter) 2>/dev/nul
 			# some idiot apropos index maker puts in "}}} {{{" before text excerpt
 			regsub -all {[][{}"]} $line "" line
 			# Solaris gives name of file, name of function within page
-			if {[string equal [lfirst $line] [lsecond $line]]} { regsub {^[ ]*[^ ]+[ ]*} $line "" line }
+			if {[lfirst $line] eq [lsecond $line]} { regsub {^[ ]*[^ ]+[ ]*} $line "" line }
 
 			if {[regexp "(\[^\t]+)\t+(.*)" $line all cmds desc]} {
 			} elseif {[regexp "(.+)  +(.*)" $line all cmds desc]} {
@@ -1381,7 +1383,7 @@ proc manHelp {w} {
 	$t image create insert -image face -align bottom -padx 8 -pady 8
 
 	set demo [file join $tk_library demos widget]
-	if [file executable $demo] {
+	if {[file executable $demo]} {
 		button $t.demo -text "run Tcl/Tk demo" -foreground $man(textfg) -background $man(textbg) -font $man(textfont) \
 			-command "exec \[info nameofexecutable\] $demo &"
 		$t window create [list [$t search "Tcl/Tk" 1.0]  lineend] -window $t.demo -align bottom -padx 8
@@ -1397,7 +1399,7 @@ proc manHelp {w} {
 			set fWarn 1
 		}
 	}
-	if $fWarn { $t insert 1.0 "Warnings\n\n" b }
+	if {$fWarn} {$t insert 1.0 "Warnings\n\n" b}
 
 	$t insert 1.0 $manx(updateinfo)
 
@@ -1438,14 +1440,14 @@ proc manKeyNav {w m k} {
 	global man manx
 
 	set t $w.show; set wi $w.info
-	if [catch {set isearch [$t index isearch.first]}] {set isearch -1}
+	if {[catch {set isearch [$t index isearch.first]}]} {set isearch -1}
 
 	set firstmode [regexp "section|apropos" $manx(mode$w)]
-	set casesen [expr $firstmode?1:$man(incr,case)]
+	set casesen [expr {$firstmode?1:$man(incr,case)}]
 
 	set fFound [searchboxKeyNav $m $k $casesen $t $wi $firstmode [expr {$manx(tryoutline$w)?"-elide":""}]]
 #	if {!$fFound && $firstmode} {set fFound [searchboxKeyNav $m $k 0 $t $wi $firstmode]}
-	if [catch {set isearch2 [$t index isearch.first]}] {set isearch2 -1}
+	if {[catch {set isearch2 [$t index isearch.first]}]} {set isearch2 -1}
 	if {$isearch2!=-1 && $isearch!=$isearch2} {manOutlineYview $t isearch.first}
 
 	return $fFound
@@ -1463,10 +1465,10 @@ proc manKeyNav {w m k} {
 proc manSave {} {
 	global man manx env
 
-	if {[string equal [file dirname $manx(startup)] "/"]} return; # no save file for root
+	if {[file dirname $manx(startup)] eq "/"} return; # no save file for root
 	if {$manx(savegeom)} {set man(geom) [wm geometry .man]}
 	set w [manPreferencesMake]
-	if [winfo exists $w] {set man(geom-prefs) [geom2posn [wm geometry $w]]}
+	if {[winfo exists $w]} {set man(geom-prefs) [geom2posn [wm geometry $w]]}
 
 	set nfn $manx(startup)
 	set ofn $manx(startup).bak
@@ -1474,7 +1476,7 @@ proc manSave {} {
 	if {![file exists $nfn] || [file writable $nfn]} {
 		# thought about making backup only if current backup is more than a day old, so don't quickly propagate error to backup copy, but need backup in order to copy user code
 		if {[file exists $nfn]} {file copy -force $nfn $ofn}
-		if [catch {set fid [open $nfn w]}] {
+		if {[catch {set fid [open $nfn w]}]} {
 			manWinstderr .man "$nfn is probably on a read-only filesystem"
 			return
 		}
@@ -1488,7 +1490,7 @@ proc manSave {} {
 			set p 0
 			while {[gets $ofid line]!=-1} {
 				if {$p} {puts $fid $line} \
-				elseif {[string equal $manx(userconfig) $line]} {set p 1}
+				elseif {$manx(userconfig) eq $line} {set p 1}
 			}
 			close $ofid
 		}
@@ -1542,7 +1544,7 @@ proc manSaveConfig {fid} {
 	# maybe iterate through default array ==> no!  won't pick up man(/<directory>)'s
 	foreach i [lsort [array names man]] {
 		if {[info exists default($i)]} {
-			set co [expr {[string equal $default($i) $man($i)]?"#":""}]
+			set co [expr {$default($i) eq $man($i)? "#" : ""}]
 			puts $fid "${co}set [list man($i)] [tr [list $man($i)] \n \n$co]"
 		} elseif {[string match "/*" $i]} {puts $fid "set man($i) $man($i)"}
 	}
@@ -1580,13 +1582,13 @@ DEBUG {puts -nonewline "manStatsSaveFile"}
 			set stats "set man($var) [list $man($var)]\n"
 
 			# rewrite variable or instantiate new variable before userconfig, if such a line exists
-			if [regsub "set man\\($var\\)\[^\}\]+\}\n" $startup $stats nstartup] {
-#			if [regsub "set man\\($var\\).*\n\}\n" $startup $stats nstartup] -- eats too much!
+			if {[regsub "set man\\($var\\)\[^\}\]+\}\n" $startup $stats nstartup]} {
+#			if {[regsub "set man\\($var\\).*\n\}\n" $startup $stats nstartup]} -- eats too much!
 				# problem copying from and into same variable, though seems to work in other cases
 				set startup $nstartup
 #puts "\n$startup\n"
 DEBUG {puts -nonewline "\tfound existing variable"}
-			} elseif [regsub "\n\n$manx(userconfig)\n" $startup "\n\n$stats\n$manx(userconfig)\n" nstartup] {
+			} elseif {[regsub "\n\n$manx(userconfig)\n" $startup "\n\n$stats\n$manx(userconfig)\n" nstartup]} {
 				set startup $nstartup
 DEBUG {puts -nonewline "\tinserted before userconfig"}
 			} else {
@@ -1636,13 +1638,13 @@ DEBUG {puts "manStatsSet"}
 	foreach i $manx(all-stats) {
 		# get cumulative value
 		if {[set index [lsearch $man(stats) $i]]>=0} {
-			set stat(cum-$i) [lindex $man(stats) [expr $index+1]]
+			set stat(cum-$i) [lindex $man(stats) [expr {$index+1}]]
 		} else {
 			set stat(cum-$i) $stat($i)
 		}
 
 		# bump up cumulative totals
-		incr stat(cum-$i) [expr $stat($i)-$stat(cur-$i)]
+		incr stat(cum-$i) [expr {$stat($i)-$stat(cur-$i)}]
 		set stat(cur-$i) $stat($i)
 
 		lappend newstats $i $stat(cum-$i)
@@ -1671,7 +1673,7 @@ DEBUG {puts "manStatsSet"}
 	append man(pagecnt) "\n"
 
 	# for counts of browses, update last element
-	set newchrono [lreplace $man(chronobrowse) end end "$manx(startuptime)/[expr [clock seconds]-$manx(startuptime)]/$manx(reading):$stat(man)/$stat(texi)/$stat(rfc)"]
+	set newchrono [lreplace $man(chronobrowse) end end "$manx(startuptime)/[expr {[clock seconds]-$manx(startuptime)}]/$manx(reading):$stat(man)/$stat(texi)/$stat(rfc)"]
 	set man(chronobrowse) "\n\t"
 	set cnt 0
 	foreach tuple $newchrono {
@@ -1765,7 +1767,7 @@ DEBUG {puts "manBinCheck on $var"}
 			} else {set pathlist $manx(bin-paths); set tail $bin}
 
 			foreach dir $pathlist {
-				if {[string equal $dir "."]} continue
+				if {$dir eq "."} continue
 				set fullpath $dir/$tail
 				# ignore file if not executable, just like shells do
 				if {[file isfile $fullpath] && [file executable $fullpath]} {
@@ -1809,7 +1811,7 @@ DEBUG { puts "$bin => $fullpath" }
 					set line ""; foreach line [split $lines "\n"] { if {$line!=""} break }
 					# grok version number
 					set vers unknown
-					if {[string equal $line ""] || ![regexp $manx(bin-versregexp) $line vers] || [package vcompare $minvers $vers]==1} {
+					if {$line eq "" || ![regexp $manx(bin-versregexp) $line vers] || [package vcompare $minvers $vers]==1} {
 						if {$minvers!=0.0} {
 							puts stderr "$bin is version $vers--must be at least $minvers."
 							incr err
@@ -1836,7 +1838,7 @@ proc manParseCommandline {} {
 	global manx argv argv0 env geometry
 
 	for {set i 0} {$i<[llength $argv]} {incr i} {
-		set arg [lindex $argv $i]; set val [lindex $argv [expr $i+1]]
+		set arg [lindex $argv $i]; set val [lindex $argv [expr {$i+1}]]
 		switch -glob -- $arg {
 			-help -
 			-h* -
@@ -1861,7 +1863,7 @@ proc manParseCommandline {} {
 			-iconbitmap {set manx(iconbitmap) $val; incr i}
 			-icon* {set manx(iconify) 1}
 			-noicon* {set manx(iconify) 0}
-			-quit {if [string match no* $val] {set manx(quit) 0}; incr i}
+			-quit {if {[string match no* $val]} {set manx(quit) 0}; incr i}
 			# put the more permissive option name patterns down below
 			-start* {set manx(startup) $val; incr i}
 			-data* {puts stderr "-database option obsolete: database kept in memory"; incr i}
@@ -1892,7 +1894,7 @@ proc ASSERT {args} {
 
 proc DEBUG {args} {
 	global manx
-	if $manx(debug) {uplevel 1 eval $args}
+	if {$manx(debug)} {uplevel 1 eval $args}
 }
 
 set manx(lastclick) 0
@@ -1900,7 +1902,7 @@ proc PROFILE {msg} {
 	global manx
 	set clicknow [clock clicks]
 # @ [clock clicks]
-	if $manx(profile) {puts "$msg, delta=[expr $clicknow-$manx(lastclick)]"}
+	if {$manx(profile)} {puts "$msg, delta=[expr {$clicknow-$manx(lastclick)}]"}
 	set manx(lastclick) $clicknow
 }
 
@@ -1914,7 +1916,7 @@ proc PROFILE {msg} {
 ##################################################
 
 ### environment checks
-if {[info tclversion]<$manx(mintcl) || $tk_version<$manx(mintk)} {
+if {[package vcompare [info tclversion] $manx(mintcl)]==-1 || [package vcompare $tk_version $manx(mintk)]==-1} {
 	puts -nonewline stderr "Tcl $manx(mintcl)/Tk $manx(mintk) minimum versions required.  "
 	puts stderr "You have Tcl [info tclversion]/Tk $tk_version"
 	exit 1
@@ -2186,7 +2188,7 @@ checkbutton .a
 #set man(textfg) []
 set man(buttfg) [set man(guifg)  [.a cget -foreground]]
 set man(guibg) [set man(buttbg) [.a cget -background]]
-#set man(textbg) "white"; if {[string equal $man(textfg) "white"]} {set man(textbg) "black"}
+#set man(textbg) "white"; if {$man(textfg) eq "white"} {set man(textbg) "black"}
 # default textbg is ugly grey
 set man(activefg) [.a cget -activeforeground]
 set man(activebg) [.a cget -activebackground]
@@ -2253,7 +2255,7 @@ foreach i [array names man] {set default($i) $man($i)}
 #
 
 set manx(title) "TkMan"
-regexp {(\d\d\d\d)/(\d\d)/(\d\d)} {$Date: 2000/03/31 22:40:51 $} manx(date) y m d
+regexp {(\d\d\d\d)/(\d\d)/(\d\d)} {$Date: 2003/04/01 23:02:52 $} manx(date) y m d
 set manx(mtime) [clock scan "$m/$d/$y"]
 set manx(stray-warnings) ""
 if {[catch {set default(manList) 0}]} {puts "\aBLT conflicts with TkMan."; exit 1}
@@ -2309,7 +2311,7 @@ set manx(bin-versregexp) {(\d+\.\d+(\.\d+)*)}; # followed by ([^,;:\s]*)
 # Glimpse min version of 4.0 so know what index looks like for index pseudovolume
 # morons maintaining glimpse exit with non-zero for version information
 #set manx(bin-versioned) {{rman "-v" 3.0.5} {glimpse "-V" 4.0} {glimpseindex "-V" 4.0}}
-set manx(bin-versioned) {{rman "-v" 3.0.5}}
+set manx(bin-versioned) {{rman "-v" 3.1}}
 set manx(modes) {man texi rfc help section txt apropos glimpse info}
 set manx(mode-desc) {"manual pages seen" "Texinfo files read" "RFC documents read" "references to help page" "volume listings invoked" "text files seen" "apropos listings" "Glimpse full-text searches" "ganders at this page"}
 DEBUG { assert [llength $manx(modes)]!=[llength $manx(mode-desc)] "mismatched modes lists" 1 }
@@ -2326,7 +2328,7 @@ set manx(zdirsect) {(?:man|sman|cat)\.?(.*)}
 # TKMAN environment variable gives standard options
 # env(TKMAN) goes first so options given on command-line override
 if {[info exists env(TKMAN)]} {set argv "$env(TKMAN) $argv"}
-if {![info exists env(PATH)] || [string equal $env(PATH) ""]} { set env(PATH) "/usr/local/bin:/usr/bin" }
+if {![info exists env(PATH)] || $env(PATH) eq ""} { set env(PATH) "/usr/local/bin:/usr/bin" }
 # don't pick up changes to env(PATH) in startup file (just so you know)
 set manx(bin-paths) [split [string trim $env(PATH) $manx(pathsep)] $manx(pathsep)]
 
@@ -2348,20 +2350,20 @@ set manx(updateinfo) ""
 # (for future references: OSF1 V3.2 on tumtum, HP-UX A.09.05 on euca)
 # Put this code after eval newuser.
 
-if {![string equal $manx(startup) ""] && ![file exists $manx(startup)] && [file writable [file dirname $manx(startup)]]} {
+if {$manx(startup) ne "" && ![file exists $manx(startup)] && [file writable [file dirname $manx(startup)]]} {
 	catch {
 	set os [string tolower $tcl_platform(os)]; set osvers $tcl_platform(osVersion)
 	set setup ""; # most OSes work without configuration file
 
 	# three trouble makers
-	if {[string equal $os "sunos"] && $osvers>=5.0} {
+	if {$os eq "sunos" && $osvers>=5.0} {
 		set setup solaris
 		if {$osvers>=5.7} {append setup "28"
 		} elseif {$osvers>=5.6} {append setup "26"
 		} elseif {$osvers>=5.5} {append setup "25"}
 	} elseif {[string match "irix*" $os]} {
 		set setup irix
-	} elseif {[string equal $os "sco_sv"]} {
+	} elseif {$os eq "sco_sv"} {
 		set setup $os
 	}
 #puts stderr "\afound $setup"
@@ -2504,7 +2506,7 @@ DEBUG {puts "*** savefilevers = $manx(savefilevers)"}
 #	}
 #}
 
-if {[string equal $man(glimpse) ""] || [string equal $man(glimpseindex) ""]} {set man(glimpse) ""; set man(glimpseindex) ""}
+if {$man(glimpse) eq "" || $man(glimpseindex) eq ""} {set man(glimpse) ""; set man(glimpseindex) ""}
 
 #if {[lsearch $man(versions) $manx(version)]==-1} {lappend man(versions) $manx(version)} -- track backtracks too
 if {[lindex $man(versions) end]!=$manx(version)} {lappend man(versions) $manx(version)}
@@ -2526,10 +2528,10 @@ foreach {name info} $man(prof) {
 set manx(highs) [concat $manx(styles) reverse underline mono $man(colors)]
 
 set manx(extravols) {}
-if {![string equal $man(apropos) ""]} {
+if {$man(apropos) ne ""} {
 	lappend manx(extravols) [list apropos "apropos hit list" [list "No apropos list" b]]
 }
-if {![string equal $man(glimpse) ""]} {
+if {$man(glimpse) ne ""} {
 	lappend manx(extravols) [list glimpse "glimpse hit list" [list "No glimpse list" b]]
 	if {$man(indexglimpse)=="unified" && [file readable [file join $man(glimpsestrays) ".glimpse_index"]]} {
 		lappend manx(extravols) [list "glimpseindex" "glimpse word index" {}]
@@ -2584,7 +2586,7 @@ set manx(binvars) {
 	man(format) man(print) man(catprint) man(apropos) man(zcat) man(compress) 
 }
 
-set manx(canformat) [expr {![string equal $man(format) ""]}]
+set manx(canformat) [expr {$man(format) ne ""}]
 if {$manx(doze)} {
     # Windoze doesn't have groff/nroff/tbl/neqn/col), glimpse, lpr, ...
     # so can't format pages, no full-text search, can't print, ...
@@ -2697,8 +2699,8 @@ if {$stat(cum-executions)==100
 if {$stat(cum-executions)%27==0} {
 	set txt ""
 	if {$man(texinfodir)==""} {append txt "+ In addition to showing manual pages, TkMan supports Texinfo (GNU documentation) with high quality text display, intra-document and full text search, highlight annotations, and an outlining interface that preserves navigation context to combat (solve?) the \"lost in info-space\" problem.  (To install, see the Makefile.)\n"}
-	if {[string equal $man(glimpse) ""]} {append txt "+ You can do full text search on all man pages, Texinfo, and other text files by installing Glimpse.  (It's is conviently available as binaries.  To install, see the Makefile.)\n"}
-	if {[string equal $man(outline) "off"]} {append txt "+ Now that you're comfortable with TkMan, try the outlining display (set Preferences/Outline/Outlining state at page load, to all collapsed but).  Rather than scolling screen after screen in a man page to find the information, outlining and Notemarks give a high density display that's likely to show the information you want on the first or second screenful.\n"}
+	if {$man(glimpse) eq ""} {append txt "+ You can do full text search on all man pages, Texinfo, and other text files by installing Glimpse.  (It's is conviently available as binaries.  To install, see the Makefile.)\n"}
+	if {$man(outline) eq "off"} {append txt "+ Now that you're comfortable with TkMan, try the outlining display (set Preferences/Outline/Outlining state at page load, to all collapsed but).  Rather than scolling screen after screen in a man page to find the information, outlining and Notemarks give a high density display that's likely to show the information you want on the first or second screenful.\n"}
 	if {$stat(cum-executions)>10 && $stat(cum-page-highlight-add)<10} {append txt "+ You can make yellow highlighter annotations.  If the page content changes or the page moves, highlights are automatically repositioned.\n"}
 	if {$stat(cum-executions)>10 && $man(outline)!="off" && $stat(cum-page-downsmart)<$stat(cum-man)/2} {append txt "+ Try using <Return> for smart scrolling through outlines, opening up closed sections as they are encountered and closing up sections as they are read.\n"}
 	if {!$man(wordfreq)} {append txt "+ You can get a kind of summary of man pages via word frequency counts (turn on at Preferences/See/Page summary).\n"}
