@@ -53,11 +53,12 @@ proc manDescDefaults {} {
 			if {[lsearch -exact $mani(manList) $num]!=-1} {set n $num} else {set n $num1}
 
 			# check for conflicts with other abbreviations starting with same letter
+			# i.e., if have <lang>/man1, disregard simple man1; if have man1, disregard cat1; but always keep sman
 			set pat "^[stringregexpesc $i]/${lang}(man|sman|cat)[stringregexpesc $dirsig]\$"
 			set dir $i/$d
 #if {[string match "*sman*" $dir]} {puts "*** setting pat: $dir"}
-#if {[string match "*sman*" $dir]} {puts "*** \[lsearch -regexp \$mani($i,dirs) $pat\]==[lsearch -regexp $mani($i,dirs) $pat]==-1 && [string equal [manPathCheckDir $dir] ""] && ![regexp {@\d+$} $dir]"}
-			if {[lsearch -regexp $mani($i,dirs) $pat]==-1 && [string equal [manPathCheckDir $dir] ""] && ![regexp {@\d+$} $dir]} {
+#if {[string match "*sman*" $dir]} {puts "*** \[lsearch -regexp \$mani($i,dirs) $pat\]==[lsearch -regexp $mani($i,dirs) $pat]==-1 && [manPathCheckDir $dir] eq "" && ![regexp {@\d+$} $dir]"}
+			if {(![string match "cat*" $d] || [lsearch -regexp $mani($i,dirs) $pat]==-1) && [manPathCheckDir $dir] eq "" && ![regexp {@\d+$} $dir]} {
 #if {[string match "*sman*" $dir]} {puts "*** appended: $dir"}
 				lappend mani($i,dirs) $dir
 				lappend mani($n,dirs) $dir
@@ -80,13 +81,13 @@ proc bytypenum {a b} {
 	set bt [string range $b 0 2]
 
 	# priority: language, type (man or cat), number, .Z suffix
-	if {![string equal $al $bl]} {
-		if {[string equal $al ""]} {return 1} elseif {[string equal $bl ""]} {return -1} elseif {$al<$bl} {return -1} else {return 1}
-	} elseif {![string equal $at $bt]} {
-		if {[string equal $at "sma"] || ([string equal $at "man"] && [string equal $bt "cat"])} {return -1} else {return 1}
-	} elseif {![string equal $as $bs]} {
+	if {$al ne $bl} {
+		if {$al eq ""} {return 1} elseif {$bl eq ""} {return -1} elseif {$al<$bl} {return -1} else {return 1}
+	} elseif {$at ne $bt} {
+		if {$at eq "sma" || ($at eq "man" && $bt eq "cat")} {return -1} else {return 1}
+	} elseif {$as ne $bs} {
 		# prefer .Z
-		if {[string equal $as ""]} {return 1} else {return -1}
+		if {$as eq ""} {return 1} else {return -1}
 	} else {
 		if {$a<$b} {return -1} else {return 1}
 	}
@@ -111,7 +112,7 @@ proc manDescAdd {to dirs} {
 
 	manDescManiCheck
 	foreach d $dirs {
-		if {![string equal [set warnmsg [manPathCheckDir $d]] ""]} {
+		if {[set warnmsg [manPathCheckDir $d]] ne ""} {
 			append warnings $warnmsg
 		} else {
 			foreach t $to {lappend mani($t,dirs) $d}
@@ -120,20 +121,20 @@ proc manDescAdd {to dirs} {
 			# in order to make them available for Glimpse indexing
 DEBUG {puts "MANPATH for $d?"}
 			set mp $d
-			while {[string match "/*" $mp] && ![string equal $mp "/"]} {
+			while {[string match "/*" $mp] && $mp ne "/"} {
 				if {[lsearch -exact $manx(paths) $mp]>=0} {
 DEBUG {puts "\tyes, in $mp"}
 					lappend mani($mp,dirs) $d; break
 				} else {set mp [file dirname $mp]}
 			}
-			if {[string equal $mp "/"]} { lappend mani($man(glimpsestrays),dirs) $d
+			if {$mp eq "/"} { lappend mani($man(glimpsestrays),dirs) $d
 DEBUG {puts "\tno, added to strays\n\t\tnow mani($man(glimpsestrays),dirs) =  $mani($man(glimpsestrays),dirs)"}
 			}
 		}
 	}
 
 
-	if {![string equal $warnings ""]} {
+	if {$warnings ne ""} {
 		if {![string match *manDescAdd* $manx(mandesc-warnings)]} {
 			append manx(mandesc-warnings) "Problems with manDescAdd's...\n"
 		}
@@ -146,8 +147,8 @@ proc manDesc {cmd from to dirs} {
 	global man manx mani
 
 	manDescManiCheck
-	if {[string equal $from "*"]} {set from $mani(manList)}
-	if {[string equal $to "*"]} {set to $mani(manList)}
+	if {$from eq "*"} {set from $mani(manList)}
+	if {$to eq "*"} {set to $mani(manList)}
 	foreach n [concat $from $to] {
 		if {[lsearch $mani(manList) $n]==-1} {
 			puts stderr "$cmd: Section letter `$n' doesn't exist."
@@ -161,9 +162,9 @@ DEBUG {puts stdout "$cmd {$from} {$to} {$dirs}"}
 			set newdir {}
 			foreach fi $mani($f,dirs) {
 				if {[string match $d $fi]} {
-					if {[string equal $cmd "copy"]} {lappend newdir $fi}
+					if {$cmd eq "copy"} {lappend newdir $fi}
 					if {[regexp "copy|move" $cmd]} {
-						foreach t $to {if {![string equal $f $t]} {lappend mani($t,dirs) $fi} else {lappend newdir $fi}}
+						foreach t $to {if {$f ne $t} {lappend mani($t,dirs) $fi} else {lappend newdir $fi}}
 					}
 				} else {lappend newdir $fi}
 			}
@@ -185,20 +186,20 @@ proc manDescAddSects {l {posn "end"} {what "n"}} {
 			continue
 		}
 
-		if {[string equal $posn "end"]} {
+		if {$posn eq "end"} {
 			lappend mani(manList) $n
 			lappend mani(manTitleList) $tit
 
-		} elseif {[string equal $posn "before"]||[string equal $posn "after"]} {
+		} elseif {$posn eq "before" || $posn eq "after"} {
 			if {[set ndx [lsearch $mani(manList) $what]]==-1} {
 				puts stderr "Requested $posn $what, but $what doesn't exist; request ignored"
 				continue
 			}
-			if {[string equal $posn "after"]} {incr ndx}
+			if {$posn eq "after"} {incr ndx}
 			set mani(manList) [linsert $mani(manList) $ndx $n]
 			set mani(manTitleList) [linsert $mani(manTitleList) $ndx $tit]
 
-		} elseif {[string equal $posn "sort"]} {
+		} elseif {$posn eq "sort"} {
 			lappend mani(manList) $n
 			set mani(manList) [lsort $mani(manList)]
 			set ndx [lsearch $mani(manList) $n]
@@ -222,7 +223,7 @@ proc manDescManiCheck {{action "exit"}} {
 		set mani(manList) $man(manList)
 		set mani(manTitleList) $man(manTitleList)
 
-		if {![info exists env(MANPATH)] || [string equal [string trim $env(MANPATH)] ""]} {
+		if {![info exists env(MANPATH)] || [string trim $env(MANPATH)] eq ""} {
 			puts stderr "You must set a MANPATH environment variable,\nwhich is a colon-separated list of directories in which\nto find man pages, for example /usr/man:/usr/share/man.\n(See the help page for an explanation of why\nalternatives to the MANPATH are a bad thing.)"
 			exit 1
 		}
@@ -230,7 +231,7 @@ proc manDescManiCheck {{action "exit"}} {
 
 		manManpathCheck
 
-		if {[string equal $action "return"]} return
+		if {$action eq "return"} return
 		manDescDefaults
 	}
 }
@@ -259,7 +260,7 @@ proc manDescSGI {patterns} {
 		#    either: 2/ftn=>2f and 3/ftn=>3ftn)  *or*  merge with ftn => 2ftn and 3ftn
 		foreach p $patlist {
 			foreach pat2 $patterns {
-				if {[string equal $pat $pat2]} break
+				if {$pat eq $pat2} break
 				set mapto2 [lfirst $pat2]; set patlist2 [lsecond $pat2]
 				foreach p2 $patlist2 {
 					if {[string match $p2 $p]} {
@@ -297,7 +298,9 @@ proc manDescSGI {patterns} {
 			# Tcl's file isdirectory dereferences symbolic links
 			# SGI's xman relies upon directories not ending in .z,
 			# don't use ![regexp $manx(zregexp) $f] as manx(zregexp) not set when this is called
-			if {![string match "*.z" $f] && ![string equal [file tail $f] "RCS"] && ![string equal [file tail $f] "RCSdiff"] && [lsearch -exact $rcats $f]==-1 && [file isdirectory $f]} {
+		    	# can't rely on pack .z compression: seen .gz, seen uncompressed -- checking for "." in filename tail (.z/.gz/.3X/...)
+# was:			if {![string match "*.z" $f]...
+			if {![regexp {/[^/]+\.[^/]+$} $f] && [file tail $f] ne "RCS" && [file tail $f] ne "RCSdiff" && [lsearch -exact $rcats $f]==-1 && [file isdirectory $f]} {
 				lappend rcats $f; lappend catmandirs $f
 			}
 		}
@@ -359,5 +362,3 @@ proc manDescShow {} {
 		puts stdout $i:$mani($i,dirs)
 	}
 }
-
-
