@@ -1,15 +1,3 @@
-# find a safe section for database build dump
-# auto change bars iff RCS'ed old version (interpret diff/ed change marks) (italics=>new, strikethrough=>deleted, bold italics=>changed=>deleted+inserted.  unfortunately on the level of lines)
-# show diff's at first, always?
-# X order: load page, attach highlights, report RCS info, user edit highlights, zap inserted text, recompute highlights ("update"?), save highlights (whew!)
-# compute diff's on rman -f ascii.  co -p << v1 | diff -w << v2 2> /dev/null (whew!)
-# + search for old version in RCS directory
-# X should probably use diff in repositioning highlights, but RCS copies likely to be scarce so not worth it
-# make this faster!  two nroffs, diff, I'm dying here.  possible to background this?
-# + database building option (alongside man pages, Texinfo) to make diff caches for all pages with RCS
-# have to put RCS files in a directory named RCS.  don't support RCS in same directory as file being RCS'ed since that would confuse other man pagers
-
-
 set man(versiondiff) 1; set manx(versiondiff-v) {1 0}; set manx(versiondiff-t) {"yes" "no"}
 set manx(edrx) {^(\d+),?(\d*)([adc])(\d+),?(\d*)$}
 
@@ -28,7 +16,7 @@ proc manVersionDiff {f w} {
 	} else return
 	if {![file readable $rcsf]} {return ""}
 
-#	if {![string equal $manx(effcols) ""]}  {
+#	if {$manx(effcols) ne ""}  {
 		set fid [open $manx(longtmp) "w"]; puts $fid ".ll $man(columns)\n.hym 20"; close $fid
 #	}
 
@@ -105,7 +93,7 @@ proc manVersionDiff {f w} {
 		catch {set diffs [eval exec [manManPipe $tail] | $format | $manx(vdiff) $tmpf -]} diffs
 #puts $diffs
 		file delete -force $tmpf
-#		if {![string equal $manx(effcols) ""]} {
+#		if {$manx(effcols) ne ""} {
 			file delete -force $manx(longtmp)
 #		}
 
@@ -120,13 +108,13 @@ proc manVersionDiff {f w} {
 			if {$keep} {incr keep -1; append newdiffs [string range $line 2 end] "\n"; continue
 			} elseif {$skip} {incr skip -1; continue}
 			if {![regexp $manx(edrx) $line all n1 n2 cmd n3 n4]} break
-			if {[string equal $n2 ""]} {set n2 $n1}; if {[string equal $n4 ""]} {set n4 $n3}
+			if {$n2 eq ""} {set n2 $n1}; if {$n4 eq ""} {set n4 $n3}
 			set lcntold [expr {$n2-$n1+1}]; set lcntnew [expr {$n4-$n3+1}]
-			if {[string equal $cmd "a"]} {
+			if {$cmd eq "a"} {
 				# already have added lines, throw them all out
 				set skip $lcntnew
 				append newdiffs "0a$lcntnew@$n3\n"
-			} elseif {[string equal $cmd "c"]} {
+			} elseif {$cmd eq "c"} {
 				# changed: keep old, skip separator and new
 
 				# first verify that changes aren't just formatting changes
@@ -139,7 +127,7 @@ proc manVersionDiff {f w} {
 				regsub -all $nrx [string trim $cold] " " ncold
 				regsub -all $nrx [string trim $cnew] " " ncnew
 
-				if {![string equal $ncold $ncnew]} {
+				if {$ncold ne $ncnew} {
 #puts "diff: $ncold\n   => $ncnew"
 					set keep $lcntold
 					set skip [expr {1+$lcntnew}]
@@ -176,7 +164,7 @@ proc manVersionDiff {f w} {
 
 		if {[file writable $cachedir]} {
 			if {[file writable $cachedir]} {
-				if {![string equal $existingcachefile ""]} {file delete $existingcachefile}
+				if {$existingcachefile ne ""} {file delete $existingcachefile}
 				#manWinstdout $w "Cacheing diffs ..." 1
 				set fid [open $cachefile "w"]; puts $fid $diffs; close $fid
 				catch {eval file delete [glob $cachefile.$manx(zglob)]}
@@ -220,7 +208,7 @@ proc manVersionDiffMakeCache {w t} {
 
 			$t insert end "[expr {$errmsg==""?"CACHEING":$errmsg}]\n"
 			update idletasks; $t see end
-			if {![string equal $errmsg ""]} continue
+			if {$errmsg ne ""} continue
 
 			foreach rcsfile [lsort -dictionary [glob -nocomplain "$rcsdir/*,v"]] {
 				foreach cols $manx(columns-v) {
@@ -239,7 +227,7 @@ proc manVersion {w t f} {
 	global man manx
 
 	set diffcnt 0
-	if {[string equal [set diffs [manVersionDiff $f $w]] ""]} {return $diffcnt}
+	if {[set diffs [manVersionDiff $f $w]] eq ""} {return $diffcnt}
 	set cmdrx {(\d+)([acd])(\d+)@(\d+)}
 
 	### apply diffs
@@ -252,7 +240,7 @@ proc manVersion {w t f} {
 	foreach line [split $diffs "\n"] {
 
 		# if comparing paragraphs, try big chunk regions
-		if {[string equal $cmd "c"] && $dell==1 && $dell0==1 && $man(columns)==5000} {
+		if {$cmd eq "c" && $dell==1 && $dell0==1 && $man(columns)==5000} {
 			set dell 0
 			set newline [$t get $ts $ts+1l]
 			set startpre 0; if {[regexp -indices "^(\\|?\[ \t]+)" $newline indices]} {
@@ -270,7 +258,7 @@ proc manVersion {w t f} {
 		# lines deleted, which we recover (insert) now
 		if {$dell} {
 #			$t insert $ts "$line" $tags
-#			if {![string equal $dell $dell0]} {$t insert "$ts lineend" "\n" $tags; incr deltal} else {incr atl}
+#			if {$dell ne $dell0} {$t insert "$ts lineend" "\n" $tags; incr deltal} else {incr atl}
 			$t insert $ts "|$line\n" $tags; incr deltal
 			set ts "[expr {$atl+$deltal}].0"
 			incr dell -1
@@ -292,8 +280,8 @@ DEBUG {puts "applying $dell *$cmd* $insl @ $atl"}
 			$t tag add diff$cmd $ts $te
 			for {set ci 0} {$ci<$insl} {incr ci} {
 				set cbi "[expr {$atl+$deltal+$ci}].0"
-				if {[string equal [$t get $cbi] ""]} {append cbi "+1c"}; # skip over outline image
-				if {![string equal [$t get $cbi] "|"]} {$t insert $cbi "|"}
+				if {[$t get $cbi] eq ""} {append cbi "+1c"}; # skip over outline image
+				if {[$t get $cbi] ne "|"} {$t insert $cbi "|"}
 			}
 #puts "$t tag add diff$cmd $ts $te"
 		}
